namespace SpreadsheetGearExplorer
{
    partial class BasicChartSample
    {
        private void ShowColumnChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing defined name.
                SpreadsheetGear.IRange source =
                    workbookView.ActiveWorkbook.Names["RegionalSales"].RefersToRange;

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to a clustered column.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.ColumnClustered;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "Regional Sales for 2007";
                chart.ChartTitle.Font.Size = 12;

                // Get a reference to the value axis and set the gridline dash style.
                SpreadsheetGear.Charts.IAxis valueAxis = 
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Value];
                valueAxis.MajorGridlines.Format.Line.DashStyle = 
                    SpreadsheetGear.Shapes.LineDashStyle.Dash;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowLineChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing defined name.
                SpreadsheetGear.IRange source =
                    workbookView.ActiveWorkbook.Names["TotalByRegion"].RefersToRange;

                // Set the chart's source data range, plotting series in rows.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Rows);

                // Set the chart type to a line chart with markers.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.LineMarkers;

                // Get a reference to the single total series.
                SpreadsheetGear.Charts.ISeries seriesTotal = chart.SeriesCollection[0];

                // Add category axis labels by using an existing defined name.
                seriesTotal.XValues = "=Regions";

                // Add series data labels and position them above the data points.
                seriesTotal.HasDataLabels = true;
                seriesTotal.DataLabels.Position = SpreadsheetGear.Charts.DataLabelPosition.Above;

                // Hide the legend.
                chart.HasLegend = false;

                // Hide the major gridlines on the value axis.
                chart.Axes[SpreadsheetGear.Charts.AxisType.Value].HasMajorGridlines = false;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "Total Sales by Region";
                chart.ChartTitle.Font.Size = 12;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowPieChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing defined name.
                SpreadsheetGear.IRange source =
                    workbookView.ActiveWorkbook.Names["TotalByQuarter"].RefersToRange;

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to a pie chart.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.Pie;

                // Get a reference to the single total series.
                SpreadsheetGear.Charts.ISeries seriesTotal = chart.SeriesCollection[0];

                // Add category labels by using an existing defined name.
                seriesTotal.XValues = "=Quarters";

                // Add series data labels and change to show percentage only.
                seriesTotal.HasDataLabels = true;
                seriesTotal.DataLabels.ShowPercentage = true;
                seriesTotal.DataLabels.ShowValue = false;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "Percentage of Sales by Quarter";
                chart.ChartTitle.Font.Size = 12;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowBarChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing defined name.
                SpreadsheetGear.IRange source =
                    workbookView.ActiveWorkbook.Names["RegionalSales"].RefersToRange;

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to a stacked bar.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.BarStacked;

                // Set the distance between bars as a percentage of the bar width.
                chart.ChartGroups[0].GapWidth = 50;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "Combined Sales by Quarter";
                chart.ChartTitle.Font.Size = 12;

                // Get a reference to the value axis and set the gridline dash style.
                SpreadsheetGear.Charts.IAxis valueAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Value];
                valueAxis.MajorGridlines.Format.Line.DashStyle =
                    SpreadsheetGear.Shapes.LineDashStyle.Dash;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowAreaChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing defined name.
                SpreadsheetGear.IRange source =
                    workbookView.ActiveWorkbook.Names["TotalByQuarter"].RefersToRange;

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to an area chart.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.Area;

                // Get a reference to the single total series.
                SpreadsheetGear.Charts.ISeries seriesTotal = chart.SeriesCollection[0];

                // Add category axis labels by using an existing defined name.
                seriesTotal.XValues = "=Quarters";

                // Change the theme color of the total series.
                seriesTotal.Format.Fill.ForeColor.ThemeColor = 
                    SpreadsheetGear.Themes.ColorSchemeIndex.Accent4;

                // Hide the legend.
                chart.HasLegend = false;

                // Hide the major gridlines on the value axis.
                chart.Axes[SpreadsheetGear.Charts.AxisType.Value].HasMajorGridlines = false;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "Total Sales by Quarter";
                chart.ChartTitle.Font.Size = 12;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private SpreadsheetGear.Charts.IChart AddChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // Get a reference to the worksheet window info and shapes collection.
            SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;
            SpreadsheetGear.IWorksheetWindowInfo windowInfo = worksheet.WindowInfo;
            SpreadsheetGear.Shapes.IShapes shapes = worksheet.Shapes;

            // Delete any existing shapes.
            while (shapes.Count != 0)
                shapes[0].Delete();

            // Add a chart to the worksheet's shape collection.
            // NOTE: Calculate the coordinates of the chart by converting row and column
            //       coordinates to points.  Use fractional row and column values to get 
            //       coordinates anywhere in between row and column boundaries.
            double left = windowInfo.ColumnToPoints(0.15);
            double top = windowInfo.RowToPoints(0.5);
            double right = windowInfo.ColumnToPoints(5.85);
            double bottom = windowInfo.RowToPoints(13.5);
            SpreadsheetGear.Charts.IChart chart =
                shapes.AddChart(left, top, right - left, bottom - top).Chart;

            // Return the chart.
            return chart;
        }
    }
}
