namespace SpreadsheetGearExplorer
{
    partial class GalleryChartSample
    {
        private void DisplayImage()
        {
            // If the picture box already has an image...
            System.Drawing.Image curImage = pictureBox.Image;
            if (curImage != null)
            {
                // Dispose the image to free resources.
                pictureBox.Image = null;
                curImage.Dispose();
            }

            // Get the currently selected category.
            string selectedCategory = listBoxCategory.Text;

            // Get the currently selected type.
            string selectedType = listBoxType.Text;

            // Get the worksheet based on the selected category name.
            SpreadsheetGear.IWorksheet worksheet = _workbook.Worksheets[selectedCategory];

            // Get the shape based on the selected type.
            SpreadsheetGear.Shapes.IShape shape = worksheet.Shapes[selectedType];

            // Create the SpreadsheetGear Image class...
            SpreadsheetGear.Drawing.Image image = new SpreadsheetGear.Drawing.Image(shape);

            // Get a new bitmap image of the represented shape.
            // NOTE: The default PixelFormat will be PixelFormat.Format32bppArgb
            //       Use the overloaded GetBitmap() method to return another format.
            System.Drawing.Bitmap bitmap = image.GetBitmap();

            // Set the new image to display in the picture box.
            pictureBox.Image = bitmap;
        }

        private void FillCategoryList()
        {
            // Clear the category list
            listBoxCategory.Items.Clear();

            // Dynamically build the category list using worksheet names.
            foreach (SpreadsheetGear.IWorksheet worksheet in _workbook.Worksheets)
                listBoxCategory.Items.Add(worksheet.Name);

            // Select the stock category.
            listBoxCategory.SelectedIndex = 6;

            // Assure that all items are displayed in each list.
            listBoxCategory.Height = listBoxType.Height = 
                System.Math.Max(listBoxCategory.PreferredHeight, listBoxType.PreferredHeight);
        }

        private void FillTypeList()
        {
            // The index of the selected type.
            int selectedIndex;

            // If we are initializing the sample...
            if (listBoxType.Items.Count == 0)
                // Set the selected index to a specific type.
                selectedIndex = 3;
            else
            {
                // Set the selected index to the first type.
                selectedIndex = 0;

                // Clear the type list.
                listBoxType.Items.Clear();
            }

            // Get the currently selected category.
            string selectedCategory = listBoxCategory.Text;

            // Get the worksheet based on the selected category name.
            SpreadsheetGear.IWorksheet worksheet = _workbook.Worksheets[selectedCategory];

            // Dynamically build the type list using shape names.
            foreach (SpreadsheetGear.Shapes.IShape shape in worksheet.Shapes)
                listBoxType.Items.Add(shape.Name);

            // Set the index of the selected type.
            listBoxType.SelectedIndex = selectedIndex;
        }
    }
}
