namespace SpreadsheetGearExplorer
{
    partial class RadarChartSample
    {
        private void AddRadarChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet, window info, and cells.
                SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;
                SpreadsheetGear.IWorksheetWindowInfo windowInfo = worksheet.WindowInfo;
                SpreadsheetGear.IRange cells = worksheet.Cells;

                // Add a chart to the worksheet's shape collection.
                // NOTE: Calculate the coordinates of the chart by converting row and column
                //       coordinates to points.  Use fractional row and column values to get 
                //       coordinates anywhere in between row and column boundaries.
                double left = windowInfo.ColumnToPoints(0.15);
                double top = windowInfo.RowToPoints(0.5);
                double right = windowInfo.ColumnToPoints(5.85);
                double bottom = windowInfo.RowToPoints(13.5);
                SpreadsheetGear.Charts.IChart chart =
                    worksheet.Shapes.AddChart(left, top, right - left, bottom - top).Chart;

                // Get the source data range from an existing defined name.
                SpreadsheetGear.IRange source =
                    workbookView.ActiveWorkbook.Names["Maintenance"].RefersToRange;

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to filled radar.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.RadarFilled;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "Seasonal Maintenance Costs";
                chart.ChartTitle.Font.Size = 12;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
