namespace SpreadsheetGearExplorer
{
    partial class StockChartSample
    {
        private void ShowHLCChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing XML File.
                SpreadsheetGear.IRange source = 
                    GetSourceData(workbookView, "stockhlc.xml");

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to a high-low-close stock chart.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.StockHLC;

                // Get a reference to the primary category axis.
                SpreadsheetGear.Charts.IAxis categoryAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Category];

                // Change the primary category axis to always use a category scale.
                categoryAxis.CategoryType = 
                    SpreadsheetGear.Charts.CategoryType.CategoryScale;

                // Set the label frequency of the primary category axis.
                categoryAxis.TickLabelSpacing = 7;

                // Get a reference to the primary value axis.
                SpreadsheetGear.Charts.IAxis valueAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Value];

                // Set the min, max, and major units of the primary value axis.
                valueAxis.MinimumScale = 80;
                valueAxis.MaximumScale = 130;
                valueAxis.MajorUnit = 10;

                // Hide the major gridlines on the primary value axis.
                valueAxis.HasMajorGridlines = false;

                // Delete the legend.
                chart.HasLegend = false;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "ABC Company (High-Low-Close)";
                chart.ChartTitle.Font.Size = 10;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowOHLCChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing XML File.
                SpreadsheetGear.IRange source = 
                    GetSourceData(workbookView, "stockohlc.xml");

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to an open-high-low-close stock chart.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.StockOHLC;

                // Get a reference to the first and only chart group.
                SpreadsheetGear.Charts.IChartGroup chartGroup = chart.ChartGroups[0];

                // Change the fill color of the down bars.
                chartGroup.DownBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Red;

                // Change the fill color of the up bars.
                chartGroup.UpBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Green;

                // Get a reference to the primary category axis.
                SpreadsheetGear.Charts.IAxis categoryAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Category];

                // Change the primary category axis to always use a category scale.
                categoryAxis.CategoryType = 
                    SpreadsheetGear.Charts.CategoryType.CategoryScale;

                // Set the label frequency of the primary category axis.
                categoryAxis.TickLabelSpacing = 7;

                // Get a reference to the primary value axis.
                SpreadsheetGear.Charts.IAxis valueAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Value];

                // Set the min, max, and major units of the primary value axis.
                valueAxis.MinimumScale = 80;
                valueAxis.MaximumScale = 130;
                valueAxis.MajorUnit = 10;

                // Hide the major gridlines on the primary value axis.
                valueAxis.HasMajorGridlines = false;

                // Delete the legend.
                chart.HasLegend = false;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "ABC Company (Open-High-Low-Close)";
                chart.ChartTitle.Font.Size = 10;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowVHLCChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing XML File.
                SpreadsheetGear.IRange source = 
                    GetSourceData(workbookView, "stockvhlc.xml");

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to a volume-high-low-close stock chart.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.StockVHLC;

                // Get a reference to the first chart group used for the volume series.
                SpreadsheetGear.Charts.IChartGroup volumeGroup = chart.ChartGroups[0];

                // Increase the volume series bar width by decreasing the gap width.
                volumeGroup.GapWidth = 75;

                // Get a reference to the primary category axis.
                SpreadsheetGear.Charts.IAxis categoryAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Category];

                // Change the primary category axis to always use a category scale.
                categoryAxis.CategoryType = 
                    SpreadsheetGear.Charts.CategoryType.CategoryScale;

                // Set the label frequency of the primary category axis.
                categoryAxis.TickLabelSpacing = 7;

                // Get a reference to the primary value axis.
                SpreadsheetGear.Charts.IAxis valueAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Value];

                // Set the min, max, and major units of the primary value axis.
                valueAxis.MinimumScale = 0;
                valueAxis.MaximumScale = 130000;
                valueAxis.MajorUnit = 26000;

                // Hide the major gridlines on the primary value axis.
                valueAxis.HasMajorGridlines = false;

                // Get a reference to the secondary value axis.
                valueAxis = chart.Axes[
                    SpreadsheetGear.Charts.AxisType.Value,
                    SpreadsheetGear.Charts.AxisGroup.Secondary];

                // Set the min, max, and major units of the secondary value axis.
                valueAxis.MinimumScale = 0;
                valueAxis.MaximumScale = 130;
                valueAxis.MajorUnit = 26;

                // Hide the major gridlines on the secondary value axis.
                valueAxis.HasMajorGridlines = false;

                // Delete the legend.
                chart.HasLegend = false;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "ABC Company (Volume-High-Low-Close)";
                chart.ChartTitle.Font.Size = 10;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowVOHLCChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a new chart.
                SpreadsheetGear.Charts.IChart chart = AddChart(workbookView);

                // Get the source data range from an existing XML File.
                SpreadsheetGear.IRange source =
                    GetSourceData(workbookView, "stockvohlc.xml");

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type to a volume-open-high-low-close stock chart.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.StockVOHLC;

                // Get a reference to the first chart group used for volume series.
                SpreadsheetGear.Charts.IChartGroup volumeGroup = chart.ChartGroups[0];

                // Increase the volume series bar width by decreasing the gap width.
                volumeGroup.GapWidth = 75;

                // Get a reference to the second chart group used for stock values.
                SpreadsheetGear.Charts.IChartGroup stockGroup = chart.ChartGroups[1];

                // Change the fill color of the down bars.
                stockGroup.DownBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Red;

                // Change the fill color of the up bars.
                stockGroup.UpBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Green;

                // Get a reference to the primary category axis.
                SpreadsheetGear.Charts.IAxis categoryAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Category];

                // Change the primary category axis to always use a category scale.
                categoryAxis.CategoryType =
                    SpreadsheetGear.Charts.CategoryType.CategoryScale;

                // Set the label frequency of the primary category axis.
                categoryAxis.TickLabelSpacing = 7;

                // Get a reference to the primary value axis.
                SpreadsheetGear.Charts.IAxis valueAxis =
                    chart.Axes[SpreadsheetGear.Charts.AxisType.Value];

                // Set the min, max, and major units of the primary value axis.
                valueAxis.MinimumScale = 0;
                valueAxis.MaximumScale = 130000;
                valueAxis.MajorUnit = 26000;

                // Hide the major gridlines on the primary value axis.
                valueAxis.HasMajorGridlines = false;

                // Get a reference to the secondary value axis.
                valueAxis = chart.Axes[
                    SpreadsheetGear.Charts.AxisType.Value,
                    SpreadsheetGear.Charts.AxisGroup.Secondary];

                // Set the min, max, and major units of the secondary value axis.
                valueAxis.MinimumScale = 0;
                valueAxis.MaximumScale = 130;
                valueAxis.MajorUnit = 26;

                // Hide the major gridlines on the secondary value axis.
                valueAxis.HasMajorGridlines = false;

                // Delete the legend.
                chart.HasLegend = false;

                // Add a chart title and change the font size.
                chart.HasTitle = true;
                chart.ChartTitle.Text = "ABC Company (Volume-Open-High-Low-Close)";
                chart.ChartTitle.Font.Size = 10;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private SpreadsheetGear.Charts.IChart AddChart(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // Get a reference to the worksheet window info and shapes collection.
            SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;
            SpreadsheetGear.IWorksheetWindowInfo windowInfo = worksheet.WindowInfo;
            SpreadsheetGear.Shapes.IShapes shapes = worksheet.Shapes;

            // Delete any existing shapes.
            while (shapes.Count != 0)
                shapes[0].Delete();

            // Add a chart to the worksheet's shape collection.
            // NOTE: Calculate the coordinates of the chart by converting row and column
            //       coordinates to points.  Use fractional row and column values to get 
            //       coordinates anywhere in between row and column boundaries.
            double left = windowInfo.ColumnToPoints(0.15);
            double top = windowInfo.RowToPoints(0.5);
            double right = windowInfo.ColumnToPoints(5.85);
            double bottom = windowInfo.RowToPoints(13.5);
            SpreadsheetGear.Charts.IChart chart =
                shapes.AddChart(left, top, right - left, bottom - top).Chart;

            // return the chart.
            return chart;
        }

        private SpreadsheetGear.IRange GetSourceData(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView, string xmlFile)
        {
            // Get a reference to the active worksheet.
            SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;

            // Clear any existing worksheet data.
            worksheet.Cells.Clear();

            // Load a data set from an XML file.
            System.Data.DataSet dataset = new System.Data.DataSet();
            dataset.ReadXml(xmlFile);

            // Get a reference to the first and only data table.
            System.Data.DataTable datatable = dataset.Tables[0];

            // Get a reference to a range matching the size of the data table.
            int row1 = 1;
            int col1 = 6;
            int row2 = row1 + datatable.Rows.Count;
            int col2 = col1 + datatable.Columns.Count - 1;
            SpreadsheetGear.IRange source = worksheet.Cells[row1, col1, row2, col2];

            // Copy the data table to the range.
            source.CopyFromDataTable(
                datatable, SpreadsheetGear.Data.SetDataFlags.None);

            // return the range.
            return source;
        }
    }
}
