namespace SpreadsheetGearExplorer
{
    partial class SimpleCommandSample
    {
        private void ExecuteCommand(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Create an instance of the simple command.
                CommandSimple command = new CommandSimple(workbookView);

                // Execute the command.
                workbookView.ActiveCommandManager.Execute(command);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void UndoCommand(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Undo the last undoable command.
                workbookView.ActiveCommandManager.Undo();
            }
            catch (System.Exception exc)
            {
                System.Windows.Forms.MessageBox.Show(exc.Message, "SpreadsheetGear");
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        /*
         * Demonstrate creating a simple undoable command which
         * toggles the display of gridlines.
         */
        private class CommandSimple : SpreadsheetGear.Commands.Command
        {
            private SpreadsheetGear.Windows.Forms.WorkbookView _workbookView;
            private bool _saveDisplayGridlines;

            public CommandSimple(
                SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
                : base(workbookView.ActiveWorkbook)
            {
                _workbookView = workbookView;
            }

            public override string DisplayText
            {
                get
                {
                    // Text displayed in Undo menu.
                    return "Toggle Display Gridlines";
                }
            }

            public override SpreadsheetGear.Commands.CommandUndoSupport UndoSupport
            {
                get
                {
                    // Undo is fully supported.
                    return SpreadsheetGear.Commands.CommandUndoSupport.Full;
                }
            }

            protected override bool Execute()
            {
                // Execute the command - we won't save state since we're
                // just toggling a boolean value.
                SpreadsheetGear.IWorksheetWindowInfo windowInfo = 
                    _workbookView.ActiveWorksheetWindowInfo;
                _saveDisplayGridlines = windowInfo.DisplayGridlines;
                windowInfo.DisplayGridlines = !_saveDisplayGridlines;
                return true;
            }

            protected override bool Undo()
            {
                // Undo the command.
                SpreadsheetGear.IWorksheetWindowInfo windowInfo =
                    _workbookView.ActiveWorksheetWindowInfo;
                windowInfo.DisplayGridlines = _saveDisplayGridlines;
                return true;
            }
        }
    }
}
