namespace SpreadsheetGearExplorer
{
    partial class ButtonSample
    {
        private void AddButton(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet and worksheet window info.
                SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;
                SpreadsheetGear.IWorksheetWindowInfo windowInfo = worksheet.WindowInfo;

                // Calculate the left, top, width and height of the button by 
                // converting row and column coordinates to points.  Use fractional 
                // values to get coordinates in between row and column boundaries.
                double left = windowInfo.ColumnToPoints(0.5);
                double top = windowInfo.RowToPoints(0.5);
                double right = windowInfo.ColumnToPoints(3.5);
                double bottom = windowInfo.RowToPoints(2.5);
                double width = right - left;
                double height = bottom - top;

                // Add the first button using the calculated bounds.
                SpreadsheetGear.Shapes.IShape shape =
                    worksheet.Shapes.AddFormControl(
                    SpreadsheetGear.Shapes.FormControlType.ButtonControl,
                    left, top, width, height);

                // Give the first button a name (used to tell the two buttons apart later).
                shape.Name = "ChangeB4";

                // Set the text of the first button.
                shape.TextFrame.Characters.Text = "Click Here to Change B4";

                // Calculate the position of the second button.
                left = windowInfo.ColumnToPoints(0.5);
                top = windowInfo.RowToPoints(5.5);
                right = windowInfo.ColumnToPoints(3.5);
                bottom = windowInfo.RowToPoints(7.5);
                width = right - left;
                height = bottom - top;

                // Add the second button using the calculated bounds.
                shape =
                    worksheet.Shapes.AddFormControl(
                    SpreadsheetGear.Shapes.FormControlType.ButtonControl,
                    left, top, width, height);

                // Give the second button a name (used to tell the two buttons apart later).
                shape.Name = "ChangeB9";

                // Set the text of the second button.
                shape.TextFrame.Characters.Text = "Click Here to Change B9";
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void workbookView_ShapeAction(
            object sender, SpreadsheetGear.Windows.Forms.ShapeActionEventArgs e)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Handle the WorkbookView.ShapeAction event in order
                // to hook into the button's Click event.
                switch (e.ShapeActionType)
                {
                    case SpreadsheetGear.Windows.Forms.ShapeActionType.Click:
                        // Get a reference to a cell.
                        SpreadsheetGear.IRange cell;
                        // Is it the first button?
                        if (e.Shape.Name.Equals("ChangeB4"))
                            cell = workbookView.ActiveWorksheet.Cells["B4"];
                        else 
                            // Assume there are only two buttons
                            cell = workbookView.ActiveWorksheet.Cells["B9"];

                        // Add text to the cell.
                        cell.Value = "SpreadsheetGear for .NET";

                        // Set various font options.
                        SpreadsheetGear.IFont font = cell.Font;
                        font.Name = "Times New Roman";
                        font.Size = 18;
                        font.Bold = true;
                        font.Color = SpreadsheetGear.Colors.SlateBlue;
                        break;
                }
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
