namespace SpreadsheetGearExplorer
{
    partial class ListBoxSample
    {
        private void AddListBox(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet and worksheet window info.
                SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;
                SpreadsheetGear.IWorksheetWindowInfo windowInfo = worksheet.WindowInfo;

                // Calculate the left, top, width and height of the listbox by 
                // converting row and column coordinates to points.  Use fractional 
                // values to get coordinates in between row and column boundaries.
                double left = windowInfo.ColumnToPoints(1.1);
                double top = windowInfo.RowToPoints(1.1);
                double right = windowInfo.ColumnToPoints(2.9);
                double bottom = windowInfo.RowToPoints(8.9);
                double width = right - left;
                double height = bottom - top;

                // Add the listbox using the calculated bounds.
                SpreadsheetGear.Shapes.IShape shape =
                    worksheet.Shapes.AddFormControl(
                    SpreadsheetGear.Shapes.FormControlType.ListBox,
                    left, top, width, height);

                // Get a reference to the control format.
                SpreadsheetGear.Shapes.IControlFormat controlFormat = shape.ControlFormat;

                // Fill the listbox with a range of existing values.
                controlFormat.ListFillRange = "A50:A61";

                // Link the listbox to cell A2.
                controlFormat.LinkedCell = "A2";

                // Select the first item in the list.
                controlFormat.ListIndex = 0;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
