namespace SpreadsheetGearExplorer
{
    partial class PageSetupSample
    {
        private void SetPageSetup(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet.
                SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;

                // Get a reference to the worksheet's page setup.
                SpreadsheetGear.IPageSetup pageSetup = worksheet.PageSetup;

                // Set the area of the worksheet to print.
                pageSetup.PrintArea = "B1:G39";

                // Scale printed output to 1 page tall by 1 page wide.
                pageSetup.FitToPages = true;
                pageSetup.FitToPagesTall = 1;
                pageSetup.FitToPagesWide = 1;

                // Horizontally center printed pages.
                pageSetup.CenterHorizontally = true;

                // Set the page orientation.
                pageSetup.Orientation = SpreadsheetGear.PageOrientation.Portrait;

                // Set page margins to 1 inch (72 points per inch)
                pageSetup.BottomMargin = 72;
                pageSetup.LeftMargin = 72;
                pageSetup.RightMargin = 72;
                pageSetup.TopMargin = 72;

                // Set custom center header text using the specified font name and size.
                pageSetup.CenterHeader = "&\"Times New Roman\"&16ABC Company Sales for 2009";

                // Set right footer to display default date and time.
                pageSetup.RightFooter = "&D &T";

                // Show a print preview of the active worksheet.
                workbookView.PrintPreview();
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
