namespace SpreadsheetGearExplorer
{
    partial class XPSDocumentSample
    {
        private void PrintToXPS(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Create a workbook print document using the active 
                // worksheet and the option to print the entire workbook.
                SpreadsheetGear.Drawing.Printing.WorkbookPrintDocument document =
                    new SpreadsheetGear.Drawing.Printing.WorkbookPrintDocument(
                    workbookView.ActiveWorksheet,
                    SpreadsheetGear.Printing.PrintWhat.Workbook);

                using (document)
                {
                    // Get a reference to the printer settings for the document.
                    System.Drawing.Printing.PrinterSettings settings = document.PrinterSettings;

                    // Set the printer driver to the Microsoft XPS Document Writer print driver. 
                    // NOTE: This could be any print driver, such as the Adobe Acrobat PDF driver.
                    settings.PrinterName = "Microsoft XPS Document Writer";

                    // If the printer driver is available...
                    if (settings.IsValid)
                    {
                        // Establish the filename to print to.
                        string filename = System.Environment.GetFolderPath(
                            System.Environment.SpecialFolder.MyDocuments) + @"\SpreadsheetGearXPSSample.xps";

                        // Enable printing to a file using the specified filename.
                        settings.PrintToFile = true;
                        settings.PrintFileName = filename;

                        // Print the workbook.
                        document.Print();

                        // Launch the XPS Viewer with the XPS document.
                        System.Diagnostics.Process.Start(filename);
                    }
                    else
                    {
                        // Show an error message.
                        System.Windows.Forms.MessageBox.Show(this, 
                            "Printer driver is not available", "SpreadsheetGear Explorer",
                            System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Error);
                    }
                }

            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
