namespace SpreadsheetGearExplorer
{
    partial class AutoFilterSample
    {
        private void FilterSingleItem(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 0;

                // Initialize criteria1 as a single product name.
                string criteria1 = "Thyme";

                // Filter by a single product.
                cell.AutoFilter(field, criteria1, 
                    SpreadsheetGear.AutoFilterOperator.Or, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterMultipleItems(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 0;

                // Initialize criteria1 as an array of product names.
                string[] criteria1 = new string[3] { "Marjoram", "Oregano", "Rosemary" };

                // Filter by multiple products.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.Values, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterTopItems(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 2;

                // Initialize criteria1 as the number of top items.
                int criteria1 = 5;

                // Filter by Q1 Top Items.
                cell.AutoFilter(field, criteria1, 
                    SpreadsheetGear.AutoFilterOperator.Top10Items, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterTopPercent(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 3;

                // Initialize criteria1 as a percentage of top items.
                int criteria1 = 10;

                // Filter by Q2 Top Percent.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.Top10Percent, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterBottomItems(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 4;

                // Initialize criteria1 as the number of bottom items.
                int criteria1 = 7;

                // Filter by Q3 Bottom Items.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.Bottom10Items, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterBottomPercent(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 5;

                // Initialize criteria1 as a percentage of bottom items.
                int criteria1 = 10;

                // Filter by Q4 Bottom Percent.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.Bottom10Percent, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterGreaterThan(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 2;

                // Initialize criteria1 using the greater than operator.
                string criteria1 = ">1850";

                // Filter by Q1 Greater Than.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.Or, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterBetween(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 3;

                // Initialize criteria1 using the greater than or equal to operator.
                string criteria1 = ">=1200";

                // Initialize criteria2 using the less than or equal to operator.
                string criteria2 = "<=1400";

                // Filter by Q2 Between.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.And, criteria2, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterColor(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 4;

                // Initialize criteria1 with a color.
                SpreadsheetGear.Color criteria1 = SpreadsheetGear.Colors.SeaGreen;

                // Filter by Q3 Color.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.CellColor, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void FilterIcon(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Clear any existing filters from the active worksheet.
                workbookView.ActiveWorksheet.AutoFilter.ShowAllData();

                // Get a reference to cell A1.
                SpreadsheetGear.IRange cell =
                    workbookView.ActiveWorksheet.Cells["A1"];

                // Initialize the field index within the auto filter range.
                int field = 5;

                // Initialize criteria1 with the first icon in the ThreeTrafficLights1 icon set.
                SpreadsheetGear.IIcon criteria1 =
                    workbookView.ActiveWorkbook.IconSets[SpreadsheetGear.IconSet.ThreeTrafficLights1][0];

                // Filter by Q4 Icon.
                cell.AutoFilter(field, criteria1,
                    SpreadsheetGear.AutoFilterOperator.Icon, null, true);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowAllData(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the AutoFilter from the worksheet.
                SpreadsheetGear.IAutoFilter autoFilter = 
                    workbookView.ActiveWorksheet.AutoFilter;

                // Clear filters to show all data in the auto filter range.
                autoFilter.ShowAllData();
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
