namespace SpreadsheetGearExplorer
{
    partial class BorderSample
    {
        private void SetTopBorder(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range = 
                    workbookView.ActiveWorksheet.Cells["B2:D8"];

                // Get a reference to the top border of the range.
                SpreadsheetGear.IBorder border =
                    range.Borders[SpreadsheetGear.BordersIndex.EdgeTop];

                // Set the border Linestyle, Weight, and Color.
                border.LineStyle = SpreadsheetGear.LineStyle.Continuous;
                border.Weight = SpreadsheetGear.BorderWeight.Thin;
                border.Color = SpreadsheetGear.Colors.Blue;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void SetLeftBorder(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["B2:D8"];

                // Get a reference to the left border of the range.
                SpreadsheetGear.IBorder border =
                    range.Borders[SpreadsheetGear.BordersIndex.EdgeLeft];

                // Set the border Linestyle, Weight, and Color.
                border.LineStyle = SpreadsheetGear.LineStyle.Continuous;
                border.Weight = SpreadsheetGear.BorderWeight.Medium;
                border.Color = SpreadsheetGear.Colors.Green;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void SetBottomBorder(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["B2:D8"];

                // Get a reference to the bottom border of the range.
                SpreadsheetGear.IBorder border =
                    range.Borders[SpreadsheetGear.BordersIndex.EdgeBottom];

                // Set the border Linestyle, Weight, and Color.
                border.LineStyle = SpreadsheetGear.LineStyle.Continuous;
                border.Weight = SpreadsheetGear.BorderWeight.Thick;
                border.Color = SpreadsheetGear.Colors.Yellow;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void SetRightBorder(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["B2:D8"];

                // Get a reference to the right border of the range.
                SpreadsheetGear.IBorder border =
                    range.Borders[SpreadsheetGear.BordersIndex.EdgeRight];

                // Set the border Linestyle, Weight, and Color.
                border.LineStyle = SpreadsheetGear.LineStyle.Double;
                border.Weight = SpreadsheetGear.BorderWeight.Thick;
                border.Color = SpreadsheetGear.Colors.Red;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void SetInsideHorizontalBorder(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["B2:D8"];

                // Get a reference to the inside horizontal border of the range.
                SpreadsheetGear.IBorder border =
                    range.Borders[SpreadsheetGear.BordersIndex.InsideHorizontal];

                // Set the border Linestyle, Weight, and Color.
                border.LineStyle = SpreadsheetGear.LineStyle.Continuous;
                border.Weight = SpreadsheetGear.BorderWeight.Thin;
                border.Color = SpreadsheetGear.Colors.DarkBlue;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void SetInsideVerticalBorder(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["B2:D8"];

                // Get a reference to the inside vertical border of the range.
                SpreadsheetGear.IBorder border =
                    range.Borders[SpreadsheetGear.BordersIndex.InsideVertical];

                // Set the border Linestyle, Weight, and Color.
                border.LineStyle = SpreadsheetGear.LineStyle.Continuous;
                border.Weight = SpreadsheetGear.BorderWeight.Thin;
                border.Color = SpreadsheetGear.Colors.DarkGreen;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void SetAllBorders(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["B2:D8"];

                // Get a reference to all the borders of the range.
                SpreadsheetGear.IBorders borders = range.Borders;

                // Set the border Linestyle, Weight, and Color.
                borders.LineStyle = SpreadsheetGear.LineStyle.Continuous;
                borders.Weight = SpreadsheetGear.BorderWeight.Medium;
                borders.Color = SpreadsheetGear.Colors.Orange;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
