namespace SpreadsheetGearExplorer
{
    partial class CommentSample
    {
        private void AddComment(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add popup comments to various cells.
                for (int i = 0; i < 5; i++)
                {
                    // Get a reference to a cell.
                    SpreadsheetGear.IRange cell =
                        workbookView.ActiveWorksheet.Cells[i * 2, i];

                    // If the cell has no comment, add one.
                    if (cell.Comment == null)
                    {
                        SpreadsheetGear.IComment comment = cell.AddComment(
                            "This comment is located in cell " + cell.Address);

                        // Turn off the default bold font.
                        comment.Shape.TextFrame.Characters.Font.Bold = false;
                        
                        // Put some text in the cell.
                        cell.Formula = "Hover over " + cell.Address + " to see comment.";
                    }
                }

                // Get a reference to a cell.
                SpreadsheetGear.IRange cell2 =
                    workbookView.ActiveWorksheet.Cells["D2"];

                // If the cell has no comment, add one.
                if (cell2.Comment == null)
                {
                    SpreadsheetGear.IComment comment = cell2.AddComment(
                        "Hover over or right click indicated cells " +
                        "to show, edit or delete comments.");

                    // Set the comment to always be visible.
                    comment.Visible = true;

                    // Turn off the default bold font.
                    comment.Shape.TextFrame.Characters.Font.Bold = false;
                }
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
