namespace SpreadsheetGearExplorer
{
    partial class ConditionalFormatSample
    {
        private void AddColorScale(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a title to a cell.
                workbookView.ActiveWorksheet.Cells["A1"].Formula = "Color Scale";

                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["A2:A11"];

                // Load data and format as $ using multiple cell range.
                range.Formula = "=ROW() * 10 - 10";
                range.NumberFormat = "$#,##0_);($#,##0)";

                // Get a reference to the range's conditional formats collection.
                SpreadsheetGear.IFormatConditions conditions = range.FormatConditions;

                // Delete any existing formats in the collection.
                conditions.Delete();

                // Add color scale conditional format.
                SpreadsheetGear.IFormatCondition condition = conditions.AddColorScale(2);

                // Get a reference to the color scale.
                SpreadsheetGear.IColorScale colorScale = condition.ColorScale;

                // Set min and max scale values.
                colorScale.ColorScaleCriteria[0].Type = SpreadsheetGear.ConditionValueTypes.Number;
                colorScale.ColorScaleCriteria[0].Value = 0;
                colorScale.ColorScaleCriteria[1].Type = SpreadsheetGear.ConditionValueTypes.Number;
                colorScale.ColorScaleCriteria[1].Value = 100;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void AddDatabar(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a title to a cell.
                workbookView.ActiveWorksheet.Cells["B1"].Formula = "Data Bar";

                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["B2:B11"];

                // Load data and format as $ using multiple cell range.
                range.Formula = "=ROW() * 10 - 10";
                range.NumberFormat = "$#,##0_);($#,##0)";

                // Get a reference to the range's conditional formats collection.
                SpreadsheetGear.IFormatConditions conditions = range.FormatConditions;

                // Delete any existing formats in the collection.
                conditions.Delete();

                // Add data bar conditional format.
                SpreadsheetGear.IFormatCondition condition = conditions.AddDatabar();

                // Get a reference to the data bar condition.
                SpreadsheetGear.IDatabar dataBar = condition.Databar;

                // Get a reference to the data bar border and apply formatting.
                SpreadsheetGear.IDataBarBorder barBorder = dataBar.BarBorder;
                barBorder.Type = SpreadsheetGear.DataBarBorderType.Solid;
                barBorder.Color.ThemeColor = SpreadsheetGear.Themes.ColorSchemeIndex.Accent1;

                // Set min and max scale values.
                dataBar.MinPoint.Modify(SpreadsheetGear.ConditionValueTypes.Number, 0);
                dataBar.MaxPoint.Modify(SpreadsheetGear.ConditionValueTypes.Number, 100);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void AddIconSet(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a title to a cell.
                workbookView.ActiveWorksheet.Cells["C1"].Formula = "Icon Set";

                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["C2:C11"];

                // Load random data and format as $ using multiple cell range.
                range.Formula = "=RAND() * 10000";
                range.NumberFormat = "$#,##0_);($#,##0)";

                // Get a reference to the range's conditional formats collection.
                SpreadsheetGear.IFormatConditions conditions = range.FormatConditions;

                // Delete any existing formats in the collection.
                conditions.Delete();

                // Add icon set conditional format.
                SpreadsheetGear.IFormatCondition condition = conditions.AddIconSetCondition();

                // Get a reference to the icon set condition.
                SpreadsheetGear.IIconSetCondition iconSet = condition.IconSetCondition;

                // Set the icon set type.
                iconSet.IconSet = workbookView.ActiveWorkbook.IconSets[SpreadsheetGear.IconSet.FiveQuarters];
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void AddTop10(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a title to a cell.
                workbookView.ActiveWorksheet.Cells["D1"].Formula = "Top 10";

                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["D2:D11"];

                // Load random data and format as $ using multiple cell range.
                range.Formula = "=RAND() * 10000";
                range.NumberFormat = "$#,##0_);($#,##0)";

                // Get a reference to the range's conditional formats collection.
                SpreadsheetGear.IFormatConditions conditions = range.FormatConditions;

                // Delete any existing formats in the collection.
                conditions.Delete();

                // Add Top 10 conditional format.
                SpreadsheetGear.IFormatCondition condition = conditions.AddTop10();

                // Get a reference to the Top 10 condition.
                SpreadsheetGear.ITop10 top10 = condition.Top10;

                // Set the rank to only format the top 2 values.
                top10.Rank = 2;

                // Set font and interior formatting options.
                condition.Font.Bold = true;
                condition.Font.Italic = true;
                condition.Font.Color = SpreadsheetGear.Colors.White;
                condition.Interior.Color = SpreadsheetGear.Colors.Green;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void AddAboveAverage(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a title to a cell.
                workbookView.ActiveWorksheet.Cells["E1"].Formula = "Above Average";

                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["E2:E11"];

                // Load random data and format as $ using multiple cell range.
                range.Formula = "=RAND() * 1000";
                range.NumberFormat = "$#,##0_);($#,##0)";

                // Get a reference to the range's conditional formats collection.
                SpreadsheetGear.IFormatConditions conditions = range.FormatConditions;

                // Delete any existing formats in the collection.
                conditions.Delete();

                // Add above average conditional format.
                SpreadsheetGear.IFormatCondition condition = conditions.AddAboveAverage();

                // Get a reference to the above average condition.
                SpreadsheetGear.IAboveAverage aboveAverage = condition.AboveAverage;

                // Display formatting for values equal or above average.
                aboveAverage.AboveBelow = SpreadsheetGear.AboveBelow.EqualAboveAverage;

                // Set font and interior formatting options.
                condition.Font.Bold = true;
                condition.Font.Italic = true;
                condition.Font.Color = SpreadsheetGear.Colors.White;
                condition.Interior.Color = SpreadsheetGear.Colors.DarkViolet;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void AddUniqueValues(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a title to a cell.
                workbookView.ActiveWorksheet.Cells["F1"].Formula = "Unique Values";

                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["F2:F11"];

                // Load random data and format as $ using multiple cell range.
                range.Formula = "=RAND() * 1000";
                range.NumberFormat = "$#,##0_);($#,##0)";

                // Set some duplicate values.
                range[2, 0].Value = 100;
                range[5, 0].Value = 100;

                // Get a reference to the range's conditional formats collection.
                SpreadsheetGear.IFormatConditions conditions = range.FormatConditions;

                // Delete any existing formats in the collection.
                conditions.Delete();

                // Add unique values conditional format.
                SpreadsheetGear.IFormatCondition condition = conditions.AddUniqueValues();

                // Get a reference to the unique values condition.
                SpreadsheetGear.IUniqueValues uniqueValues = condition.UniqueValues;

                // Display formatting for values that are duplicates.
                uniqueValues.DupeUnique = SpreadsheetGear.DupeUnique.Duplicate;

                // Set font and interior formatting options.
                condition.Font.Bold = true;
                condition.Font.Italic = true;
                condition.Interior.Color = SpreadsheetGear.Colors.LightSalmon;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void AddCellValue(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Add a title to a cell.
                workbookView.ActiveWorksheet.Cells["G1"].Formula = "Cell Value";

                // Get a reference to a range of cells.
                SpreadsheetGear.IRange range =
                    workbookView.ActiveWorksheet.Cells["G2:G11"];

                // Load random data and format as $ using multiple cell range.
                range.Formula = "=RAND() * 10000";
                range.NumberFormat = "$#,##0_);($#,##0)";

                // Get a reference to the range's conditional formats collection.
                SpreadsheetGear.IFormatConditions conditions = range.FormatConditions;

                // Delete any existing formats in the collection.
                conditions.Delete();

                // Add a conditional format for values less than or equal to 7000.
                SpreadsheetGear.IFormatCondition condition = conditions.Add(
                    SpreadsheetGear.FormatConditionType.CellValue,
                    SpreadsheetGear.FormatConditionOperator.LessEqual, "7000", null);

                // Set font and interior formatting options.
                condition.Font.Bold = false;
                condition.Font.Color = SpreadsheetGear.Colors.White;
                condition.Interior.Color = SpreadsheetGear.Colors.DarkSlateBlue;

                // Add a conditional format for values greater than 7000.
                condition = conditions.Add(
                    SpreadsheetGear.FormatConditionType.CellValue,
                    SpreadsheetGear.FormatConditionOperator.Greater, "7000", null);

                // Set font and interior formatting options.
                condition.Font.Bold = true;
                condition.Font.Italic = true;
                condition.Font.Color = SpreadsheetGear.Colors.White;
                condition.Interior.Color = SpreadsheetGear.Colors.Maroon;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void Recalc(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Recalculate the random values.
                workbookView.ActiveWorkbookSet.Calculate();
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
