namespace SpreadsheetGearExplorer
{
    partial class FindReplaceSample
    {
        private void FindNext(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the worksheet's cells.
                SpreadsheetGear.IRange cells = workbookView.ActiveWorksheet.Cells;

                // Get a reference to the active cell.
                SpreadsheetGear.IRange activeCell = workbookView.ActiveCell;

                // Find the next cell after the active cell which contains the word "Text".
                // Require only a partial match by specifying LookAt.Part.
                SpreadsheetGear.IRange findCell = cells.Find("Text", activeCell, 
                    SpreadsheetGear.FindLookIn.Formulas, SpreadsheetGear.LookAt.Part, 
                    SpreadsheetGear.SearchOrder.ByRows, SpreadsheetGear.SearchDirection.Next, false);

                // If a cell was found, select it, otherwise show an error.
                if (findCell != null)
                    findCell.Select();
                else
                {
                    System.Windows.Forms.MessageBox.Show(
                        "No match was found.", "SpreadsheetGear");
                }
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void Replace(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the worksheet's cells.
                SpreadsheetGear.IRange cells = workbookView.ActiveWorksheet.Cells;

                // Replace all occurences of the word "Text" with "New Text".
                // Require an exact match by specifying LookAt.Whole.
                int replaceCount = cells.Replace("Text", "New Text",
                    SpreadsheetGear.LookAt.Whole, SpreadsheetGear.SearchOrder.ByRows, false);

                // Show an error if nothing was replaced.
                if (replaceCount == 0)
                {
                    System.Windows.Forms.MessageBox.Show(
                        "No cells were replaced.", "SpreadsheetGear");
                }
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
