namespace SpreadsheetGearExplorer
{
    partial class HyperlinkSample
    {
        private void AddHyperlink(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet.
                SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;

                // Get a reference to the worksheet's hyperlink collection.
                SpreadsheetGear.IHyperlinks hyperlinks = worksheet.Hyperlinks;

                // Delete all hyperlinks in the collection.
                hyperlinks.Delete();
                
                // Add a hyperlink referencing a range.
                hyperlinks.Add(
                    worksheet.Cells["A2"], null, "C:C", null, "Column C");

                // Add a hyperlink referencing a range on another worksheet.
                hyperlinks.Add(
                    worksheet.Cells["A3"], null, "Sheet2!A1:D4", null, "Range on Sheet2");

                // Add a hyperlink referencing a web page.
                hyperlinks.Add(
                    worksheet.Cells["A4"], 
                    @"http://www.spreadsheetgear.com", 
                    null, null, "www.spreadsheetgear.com");

                // Add a hyperlink referencing an email address.
                hyperlinks.Add(
                    worksheet.Cells["A5"],
                    "mailto:sales@spreadsheetgear.com",
                    null, null, "sales@spreadsheetgear.com");

                // Add a hyperlink referencing an email address with a subject.
                hyperlinks.Add(
                    worksheet.Cells["A6"],
                    "mailto:support@spreadsheetgear.com?subject=Support Request",
                    null, null, "support@spreadsheetgear.com");

                // Add some text and set the column width.
                worksheet.Cells["A1"].Formula = "Hyperlink Examples";
                worksheet.Cells["A1"].ColumnWidth = 30;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
