namespace SpreadsheetGearExplorer
{
    partial class InteriorSample
    {
        private void SetInterior(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet's cells.
                SpreadsheetGear.IRange cells = workbookView.ActiveWorksheet.Cells;

                // Set B2:C4 to a solid blue.
                SpreadsheetGear.IInterior interior = cells["B2:C4"].Interior;
                interior.Color = SpreadsheetGear.Colors.Blue;

                // Set B6:C8 to a red and yellow pattern.
                interior = cells["B6:C8"].Interior;
                interior.Color = SpreadsheetGear.Colors.Red;
                interior.Pattern = SpreadsheetGear.Pattern.Gray16;
                interior.PatternColor = SpreadsheetGear.Colors.Yellow;

                // Set E2:F4 to a linear gradient.
                interior = cells["E2:F4"].Interior;
                interior.Pattern = SpreadsheetGear.Pattern.LinearGradient;

                // Merge the cells.
                cells["E2:F4"].Merge();

                // Get a reference to the linear gradient.
                SpreadsheetGear.ILinearGradient linearGradient = 
                    interior.Gradient as SpreadsheetGear.ILinearGradient;

                // Set the angle of the linear gradient to 90 degrees.
                linearGradient.Degree = 90;

                // Set E6:F8 to a rectangular gradient.
                interior = cells["E6:F8"].Interior;
                interior.Pattern = SpreadsheetGear.Pattern.RectangularGradient;

                // Merge the cells.
                cells["E6:F8"].Merge();

                // Get a reference to the rectangular gradient.
                SpreadsheetGear.IRectangularGradient rectGradient =
                    interior.Gradient as SpreadsheetGear.IRectangularGradient;

                // Set the rectangular gradient to fill from center.
                rectGradient.RectangleBottom = 0.5;
                rectGradient.RectangleLeft = 0.5;
                rectGradient.RectangleRight = 0.5;
                rectGradient.RectangleTop = 0.5;

                // Get a reference to the rectangular gradient color stops.
                SpreadsheetGear.IColorStops colorStops = rectGradient.ColorStops;

                // Clear the default color stops.
                colorStops.Clear();

                // Add custom color stops.
                colorStops.Add(0.0).Color = SpreadsheetGear.Colors.White;
                colorStops.Add(1.0).ThemeColor = SpreadsheetGear.Themes.ColorSchemeIndex.Accent6;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}

