namespace SpreadsheetGearExplorer
{
    partial class LockingSample
    {
        private void SetLocked(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet.
                SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;

                // Is the worksheet already protected?
                if (worksheet.ProtectContents != true)
                {
                    // Add a couple of labels and autofit the column.
                    SpreadsheetGear.IRange cells = worksheet.Cells;
                    cells["A1"].Value = "Row 1 is not locked - you can edit this cell.";
                    cells["A2"].Value = "All other rows are locked - you cannot edit this cell.";
                    cells["A1:A2"].Columns.AutoFit();

                    // Get a reference to row 1.
                    SpreadsheetGear.IRange row1 = cells["1:1"];

                    // Unlock the range of cells. (NOTE: Cells are locked by default)
                    row1.Locked = false;

                    // Enable protection for the worksheet.
                    worksheet.ProtectContents = true;
                }

                // Give the keyboard focus to the WorkbookView.
                workbookView.Focus();
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
