namespace SpreadsheetGearExplorer
{
    partial class FormulasFormatsSample
    {
        private void RunReport(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a workbook reference.
                SpreadsheetGear.IWorkbook workbook = workbookView.ActiveWorkbook;

                // Get a worksheet and change the name.
                SpreadsheetGear.IWorksheet worksheet = workbook.Worksheets[0];
                worksheet.Name = "2005 Sales";

                // Get the worksheet cells reference.
                SpreadsheetGear.IRange cells = worksheet.Cells;

                // Add column headers.
                cells["B1"].Formula = "Jan";
                cells["C1"].Formula = "Feb";
                cells["D1"].Formula = "Mar";

                // Add row headers.
                cells["A2"].Formula = "West";
                cells["A3"].Formula = "Central";
                cells["A4"].Formula = "East";

                // Add random data.
                cells["B2:D4"].Formula = "=RAND()*10000";

                // Center the column headers.
                cells["B1:D1"].HorizontalAlignment = SpreadsheetGear.HAlign.Center;

                // Bold the row and column headers.
                cells["B1:D1,A2:A4"].Font.Bold = true;

                // Add defined names.
                SpreadsheetGear.INames names = workbook.Names;
                names.Add("Jan", "='2005 Sales'!$B$2:$B$4");
                names.Add("Feb", "='2005 Sales'!$C$2:$C$4");
                names.Add("Mar", "='2005 Sales'!$D$2:$D$4");
                names.Add("Sales", "='2005 Sales'!$B$2:$D$4");

                // Format sales data as currency.
                cells["Sales"].NumberFormat = "$#,##0";

                // Add a hyperlink.
                worksheet.Hyperlinks.Add(
                    cells["A6"], @"http://www.spreadsheetgear.com",
                    null, "SpreadsheetGear Home Page", "SpreadsheetGear Home Page");

                // Merge some cells.
                cells["A6:C6"].Merge();
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
