namespace SpreadsheetGearExplorer
{
    partial class SimpleSpreadsheetSample
    {
        private void RunReport(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a workbook reference.
                SpreadsheetGear.IWorkbook workbook = workbookView.ActiveWorkbook;
                // Get a worksheet reference.
                SpreadsheetGear.IWorksheet worksheet = workbook.Worksheets[0];
                // Get the worksheet cells reference.
                SpreadsheetGear.IRange cells = worksheet.Cells;

                // Set the worksheet name.
                worksheet.Name = "2006 Sales";

                // Load column titles and center.
                cells["B1"].Formula = "North";
                cells["C1"].Formula = "South";
                cells["D1"].Formula = "East";
                cells["E1"].Formula = "West";
                cells["B1:E1"].HorizontalAlignment = SpreadsheetGear.HAlign.Center;

                // Load row titles using multiple cell text reference and iteration.
                int quarter = 1;
                foreach (SpreadsheetGear.IRange cell in cells["A2:A5"])
                    cell.Formula = "Q" + quarter++;

                // Load random data and format as $ using multiple cell range.
                SpreadsheetGear.IRange body = cells[1, 1, 4, 4];
                body.Formula = "=RAND() * 10000";
                body.NumberFormat = "$#,##0_);($#,##0)";
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
