namespace SpreadsheetGearExplorer
{
    partial class WorkbookConsolidationSample
    {
        private void RunReport(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                SpreadsheetGear.IWorkbook workbook;
                if (radioButtonAll.Checked)
                {
                    // Create a new workbook and name the first sheet.
                    workbook = SpreadsheetGear.Factory.GetWorkbook(System.Globalization.CultureInfo.CurrentCulture);
                    SpreadsheetGear.IWorksheet worksheet = workbook.Worksheets[0];
                    worksheet.Name = "Total Sales";

                    // Copy all region templates to the new worksheet.
                    CopyRegion(worksheet, "North", 
                        SpreadsheetGear.PasteOperation.None);
                    CopyRegion(worksheet, "South", 
                        SpreadsheetGear.PasteOperation.Add);
                    CopyRegion(worksheet, "East", 
                        SpreadsheetGear.PasteOperation.Add);
                    CopyRegion(worksheet, "West", 
                        SpreadsheetGear.PasteOperation.Add);

                    // Auto size all worksheet columns which contain data.
                    worksheet.UsedRange.Columns.AutoFit();
                }
                else
                {
                    // Get the region that is selected.
                    string region;
                    if (radioButtonNorth.Checked)
                        region = "North";
                    else if (radioButtonSouth.Checked)
                        region = "South";
                    else if (radioButtonEast.Checked)
                        region = "East";
                    else
                        region = "West";

                    // Get a workbook for the selected region.
                    workbook = GetWorkbookForRegion(region);
                }

                // Set the new workbook as the active workbook.
                workbookView.ActiveWorkbook = workbook;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void CopyRegion(
            SpreadsheetGear.IWorksheet dstWorksheet, 
            string region, SpreadsheetGear.PasteOperation pasteOperation)
        {
            // Open the specified region workbook and get the source range.
            SpreadsheetGear.IWorkbook srcWorkbook = GetWorkbookForRegion(region);
            SpreadsheetGear.IRange srcRange = 
                srcWorkbook.Names["YearSales"].RefersToRange;

            // Set up our destination range to match the size of the source range.
            string address = srcRange.Address;
            SpreadsheetGear.IRange dstRange = dstWorksheet.Cells[address];

            // Copy the source range values and formats to the destination range.
            // We have to call copy twice here since there is currently no PasteType
            // which does values and all formats together. This is a limitaion in 
            // the Excel API, but probably should be added to the SpreadsheetGear API.
            srcRange.Copy(dstRange,
                SpreadsheetGear.PasteType.Values,
                pasteOperation, true, false);

            srcRange.Copy(dstRange,
                SpreadsheetGear.PasteType.Formats,
                pasteOperation, true, false);

            // Set the destination worksheet row heights to match the source range.
            dstWorksheet.Cells.RowHeight = srcRange.RowHeight;
        }

        private SpreadsheetGear.IWorkbook GetWorkbookForRegion(string region)
        {
            // Get the filename from the region name.
            string filename;
            switch (region)
            {
                case "North":
                default:
                    filename = "spicenorth.xls";
                    break;
                case "South":
                    filename = "spicesouth.xls";
                    break;
                case "East":
                    filename = "spiceeast.xls";
                    break;
                case "West":
                    filename = "spicewest.xls";
                    break;
            }

            // Return a workbook from the filename.
            return SpreadsheetGear.Factory.GetWorkbook(filename, System.Globalization.CultureInfo.CurrentCulture);
        }
    }
}
