namespace SpreadsheetGearExplorer
{
    partial class DisplayReferenceSample
    {
        private void radioButton_CheckedChanged(
            object sender, System.EventArgs e)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                if (radioButtonWorkbook.Checked)
                {
                    // Change the display reference to an entire workbook.
                    workbookView.DisplayReference = "Book2";
                    workbookView.DisplayReferenceName = null;
                }
                else if (radioButtonWorksheet.Checked)
                {
                    // Change the display reference to an entire worksheet.
                    //
                    // Note that this sample uses single quotes around the reference 
                    // because the sheet name has a space in it.
                    workbookView.DisplayReference = "'[Book1]My Worksheet'!A:XFD";

                    // Change the text displayed in the WorkbookView tabs.
                    workbookView.DisplayReferenceName = "\"My Worksheet Tab\"";
                }
                else if (radioButtonRange.Checked)
                {
                    // Change the display reference to a single range.
                    workbookView.DisplayReference = "[Book3]Sheet2!A1:E8";

                    // Change the text displayed in the WorkbookView tabs.
                    workbookView.DisplayReferenceName = "\"My Range\"";

                    // Change the extra color diplayed beyond the last row and column.
                    workbookView.ExtraColor = System.Drawing.Color.SlateBlue;
                }
                else if (radioButtonDefinedName.Checked)
                {
                    // Change the display reference to a defined name.
                    workbookView.DisplayReference = "Book2!MyName";

                    // Change the text displayed in the WorkbookView tabs.
                    workbookView.DisplayReferenceName = "\"My Defined Name\"";

                    // Change the extra color diplayed beyond the last row and column.
                    workbookView.ExtraColor = System.Drawing.Color.SlateBlue;
                }
                else if (radioButtonMultipleRanges.Checked)
                {
                    // Change the display reference to multiple ranges.
                    workbookView.DisplayReference =
                        "[Book1]Sheet1!A1:D5,[Book1]Sheet1!4:6,[Book1]Sheet1!D:F";

                    // Change the text displayed in the WorkbookView tabs.
                    workbookView.DisplayReferenceName =
                        "\"My Range1\",\"My Range2\",\"My Range3\"";

                    // Change the extra color diplayed beyond the last row and column.
                    workbookView.ExtraColor = System.Drawing.Color.SlateBlue;
                }
                else if (radioButtonUsedRange.Checked)
                {
                    // Get a reference to a workbook.
                    SpreadsheetGear.IWorkbook workbook = 
                        workbookView.ActiveWorkbookSet.Workbooks["Book4"];

                    // Get a reference to the workbook's worksheet collection.
                    SpreadsheetGear.IWorksheets worksheets = workbook.Worksheets;

                    // Get the name of the workbook.
                    string bookName = workbook.Name;

                    // Get the last sheet index.
                    int lastSheetIndex = worksheets.Count - 1;

                    // Initialize the display reference variable.
                    string displayReference = "";

                    // Dynamically build a display reference which will include
                    // the used portion of all worksheets in the workbook.
                    for (int sheetIndex = 0; sheetIndex <= lastSheetIndex; sheetIndex++)
                    {
                        // Get a reference to the worksheet at the specified index.
                        SpreadsheetGear.IWorksheet worksheet = worksheets[sheetIndex];

                        // Get a reference to the used area of the worksheet.
                        SpreadsheetGear.IRange usedRange = worksheet.UsedRange;

                        // Get the name of the worksheet.
                        string sheetName = worksheet.Name;

                        // Get the range address of the used range.
                        string rangeName = usedRange.Address;

                        // Append the information to the display reference.
                        displayReference += "'[" + bookName + "]" + sheetName + "'!" + rangeName;

                        // Add a separator if there are more ranges to add.
                        if (sheetIndex < lastSheetIndex)
                            displayReference += ",";
                    }

                    // Set the display reference.
                    workbookView.DisplayReference = displayReference;

                    // Clear display names so that the actual worksheet names are used.
                    workbookView.DisplayReferenceName = null;

                    // Change the extra color diplayed beyond the last row and column.
                    workbookView.ExtraColor = System.Drawing.Color.SlateBlue;
                }
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
