namespace SpreadsheetGearExplorer
{
    partial class WorksheetWindowInfoSample
    {
        private void FreezePanes(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet window info.
                SpreadsheetGear.IWorksheetWindowInfo windowInfo = 
                    workbookView.ActiveWorksheetWindowInfo;

                // Display the first row at the top.
                windowInfo.ScrollRow = 0;

                // Display the first column at the left.
                windowInfo.ScrollColumn = 0;

                // Split two rows.
                windowInfo.SplitRows = 2;

                // Split one column.
                windowInfo.SplitColumns = 1;

                // Freeze the top and left panes.
                windowInfo.FreezePanes = true;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void DisplayGridlines(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet window info.
                SpreadsheetGear.IWorksheetWindowInfo windowInfo = 
                    workbookView.ActiveWorksheetWindowInfo;

                // Display gridlines.
                windowInfo.DisplayGridlines = true;

                // Set the color of the gridlines.
                windowInfo.GridlineColor = SpreadsheetGear.Colors.SlateBlue;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ToggleHeadings(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the active worksheet window info.
                SpreadsheetGear.IWorksheetWindowInfo windowInfo =
                    workbookView.ActiveWorksheetWindowInfo;

                // Toggle display of row and column headings.
                windowInfo.DisplayHeadings = !windowInfo.DisplayHeadings;
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void Zoom(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to a cell and it's font.
                SpreadsheetGear.IRange cell = 
                    workbookView.ActiveWorksheet.Cells["B3"];
                SpreadsheetGear.IFont font = cell.Font;

                // Add text and set font options.
                cell.Value = "SpreadsheetGear for .NET";
                font.Name = "Times New Roman";
                font.Bold = true;
                font.Color = SpreadsheetGear.Colors.SlateBlue;

                // Get a reference to the active worksheet window info.
                SpreadsheetGear.IWorksheetWindowInfo windowInfo = 
                    workbookView.ActiveWorksheetWindowInfo;

                while (windowInfo.Zoom < 400)
                {
                    // Set the zoom factor.
                    windowInfo.Zoom = windowInfo.Zoom + 10;

                    // NOTE: This call to Refresh is not required and is only
                    //       here for sample purposes to update the control.
                    workbookView.Refresh();
                }

                while (windowInfo.Zoom > 100)
                {
                    // Set the zoom factor.
                    windowInfo.Zoom = windowInfo.Zoom - 10;

                    // NOTE: This call to Refresh is not required and is only
                    //       here for sample purposes to update the control.
                    workbookView.Refresh();
                }
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }
    }
}
