namespace SpreadsheetGearExplorer
{
    partial class FormSample
    {
        private void ShowWorkbookDesigner(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get the active workbook set.
                SpreadsheetGear.IWorkbookSet workbookSet = workbookView.ActiveWorkbookSet;

                // Create the Workbook Designer for the active workbook set.
                SpreadsheetGear.Windows.Forms.WorkbookDesigner designer =
                    new SpreadsheetGear.Windows.Forms.WorkbookDesigner(workbookSet);

                // Set up some event handlers.
                designer.Shown += 
                    new System.EventHandler(workbookDesigner_Shown);
                designer.FormClosed += 
                    new System.Windows.Forms.FormClosedEventHandler(workbookDesigner_FormClosed);

                // Display the Workbook Designer to the user.
                designer.Show(workbookView);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowWorkbookExplorer(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get the active workbook set.
                SpreadsheetGear.IWorkbookSet workbookSet = workbookView.ActiveWorkbookSet;

                // Create the Workbook Explorer for the active workbook set.
                SpreadsheetGear.Windows.Forms.WorkbookExplorer explorer =
                    new SpreadsheetGear.Windows.Forms.WorkbookExplorer(workbookSet);

                // Set up some event handlers.
                explorer.Shown +=
                    new System.EventHandler(workbookExplorer_Shown);
                explorer.FormClosed +=
                    new System.Windows.Forms.FormClosedEventHandler(workbookExplorer_FormClosed);

                // Display the Workbook Explorer to the user.
                explorer.Show(workbookView);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowRangeExplorer(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Select a range of cells.
                workbookView.ActiveWorksheet.Cells["B2:D3"].Select();

                // Get the active workbook set.
                SpreadsheetGear.IWorkbookSet workbookSet = workbookView.ActiveWorkbookSet;

                // Set up the categories to display in the Range Explorer.
                // NOTE: This enumeration can be used to limit available categories.
                SpreadsheetGear.Windows.Forms.RangeExplorerCategoryFlags 
                    categoryFlags = SpreadsheetGear.Windows.Forms.RangeExplorerCategoryFlags.All;

                // Create the Range Explorer which operates on the current range selection.
                SpreadsheetGear.Windows.Forms.RangeExplorer explorer =
                    new SpreadsheetGear.Windows.Forms.RangeExplorer(workbookSet, categoryFlags);

                // Set up some event handlers.
                explorer.Shown +=
                    new System.EventHandler(rangeExplorer_Shown);
                explorer.FormClosed +=
                    new System.Windows.Forms.FormClosedEventHandler(rangeExplorer_FormClosed);

                // Display the Range Explorer to the user.
                explorer.Show(workbookView);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowChartExplorer(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the worksheet's shapes collection.
                SpreadsheetGear.IWorksheet worksheet = workbookView.ActiveWorksheet;
                SpreadsheetGear.Shapes.IShapes shapes = worksheet.Shapes;

                // Delete any existing shapes.
                while (shapes.Count != 0)
                    shapes[0].Delete();

                // Load some sample data.
                SpreadsheetGear.IRange dataRange = worksheet.Cells["A101:C105"];
                dataRange.Formula = "=INT(RAND() * 10 + 5)";

                // Add a chart.
                SpreadsheetGear.Shapes.IShape shape = shapes.AddChart(10, 10, 320, 150);
                SpreadsheetGear.Charts.IChart chart = shape.Chart;

                // Set the chart's source data range, plotting series in columns.
                chart.SetSourceData(dataRange, SpreadsheetGear.Charts.RowCol.Columns);

                // Set the chart type.
                chart.ChartType = SpreadsheetGear.Charts.ChartType.ColumnClustered;

                // Select the chart shape.
                shape.Select(true);

                // Get the active workbook set.
                SpreadsheetGear.IWorkbookSet workbookSet = workbookView.ActiveWorkbookSet;

                // Set up the categories to display in the Chart Explorer.
                // NOTE: This enumeration can be used to limit available categories.
                SpreadsheetGear.Windows.Forms.ChartExplorerCategoryFlags
                    categoryFlags = SpreadsheetGear.Windows.Forms.ChartExplorerCategoryFlags.All;

                // Create the Chart Explorer which operates on the current chart selection.
                SpreadsheetGear.Windows.Forms.ChartExplorer explorer =
                    new SpreadsheetGear.Windows.Forms.ChartExplorer(workbookSet, categoryFlags);

                // Set up some event handlers.
                explorer.Shown +=
                    new System.EventHandler(chartExplorer_Shown);
                explorer.FormClosed +=
                    new System.Windows.Forms.FormClosedEventHandler(chartExplorer_FormClosed);

                // Display the Chart Explorer to the user.
                explorer.Show(workbookView);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        private void ShowShapeExplorer(
            SpreadsheetGear.Windows.Forms.WorkbookView workbookView)
        {
            // NOTE: Must acquire a workbook set lock.
            workbookView.GetLock();
            try
            {
                // Get a reference to the worksheet's shapes collection.
                SpreadsheetGear.Shapes.IShapes shapes = workbookView.ActiveWorksheet.Shapes;

                // Delete any existing shapes.
                while (shapes.Count != 0)
                    shapes[0].Delete();

                // Add a trapezoid.
                SpreadsheetGear.Shapes.IShape shape = shapes.AddShape(
                    SpreadsheetGear.Shapes.AutoShapeType.Trapezoid, 24, 24, 96, 96);

                // Select the trapezoid.
                shape.Select(true);

                // Get the active workbook set.
                SpreadsheetGear.IWorkbookSet workbookSet = workbookView.ActiveWorkbookSet;

                // Set up the categories to display in the Shape Explorer.
                // NOTE: This enumeration can be used to limit available categories.
                SpreadsheetGear.Windows.Forms.ShapeExplorerCategoryFlags
                    categoryFlags = SpreadsheetGear.Windows.Forms.ShapeExplorerCategoryFlags.All;

                // Create the Shape Explorer which operates on the current shape selection.
                SpreadsheetGear.Windows.Forms.ShapeExplorer explorer =
                    new SpreadsheetGear.Windows.Forms.ShapeExplorer(workbookSet, categoryFlags);

                // Set up some event handlers.
                explorer.Shown +=
                    new System.EventHandler(shapeExplorer_Shown);
                explorer.FormClosed +=
                    new System.Windows.Forms.FormClosedEventHandler(shapeExplorer_FormClosed);

                // Display the Shape Explorer to the user.
                explorer.Show(workbookView);
            }
            finally
            {
                // NOTE: Must release the workbook set lock.
                workbookView.ReleaseLock();
            }
        }

        // The following event handlers are only used to enable and
        // disable the buttons used to display each individual form.

        private void workbookDesigner_Shown(object sender, System.EventArgs e)
        {
            buttonWorkbookDesigner.Enabled = false;
        }

        private void workbookDesigner_FormClosed(object sender, System.Windows.Forms.FormClosedEventArgs e)
        {
            buttonWorkbookDesigner.Enabled = true;
        }

        private void workbookExplorer_Shown(object sender, System.EventArgs e)
        {
            buttonWorkbookExplorer.Enabled = false;
        }

        private void workbookExplorer_FormClosed(object sender, System.Windows.Forms.FormClosedEventArgs e)
        {
            buttonWorkbookExplorer.Enabled = true;
        }

        private void rangeExplorer_Shown(object sender, System.EventArgs e)
        {
            buttonRangeExplorer.Enabled = false;
        }

        private void rangeExplorer_FormClosed(object sender, System.Windows.Forms.FormClosedEventArgs e)
        {
            buttonRangeExplorer.Enabled = true;
        }

        private void chartExplorer_Shown(object sender, System.EventArgs e)
        {
            buttonChartExplorer.Enabled = false;
        }

        private void chartExplorer_FormClosed(object sender, System.Windows.Forms.FormClosedEventArgs e)
        {
            buttonChartExplorer.Enabled = true;
        }

        private void shapeExplorer_Shown(object sender, System.EventArgs e)
        {
            buttonShapeExplorer.Enabled = false;
        }

        private void shapeExplorer_FormClosed(object sender, System.Windows.Forms.FormClosedEventArgs e)
        {
            buttonShapeExplorer.Enabled = true;
        }
    }
}
