using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace SpreadsheetGearNavigator
{
    /// <summary>
    /// This class is only used to navigate the SpreadsheetGear Explorer.  
    /// </summary>
    public partial class ExplorerView : UserControl
    {
        public ExplorerView()
        {
            InitializeComponent();
        }

        public void SetSampleControlAssembly(System.Reflection.Assembly assembly)
        {
            sampleContainer.SetSampleControlAssembly(assembly);
        }

        private void navigationControl1_NavigationChanged(object sender, TreeViewEventArgs e)
        {
            TreeNode node = e.Node;
            string nodeName = node.Name;
            string nodeText = node.Text;
            if (nodeName.Contains("Sample"))
            {
                string codeText;
                Exception exc;
                ISampleControl sampleControl = sampleContainer.LoadSampleControl(nodeName, out exc);
                if (exc != null)
                {
                    if (exc.InnerException != null)
                        codeText = exc.InnerException.Message;
                    else
                        codeText = exc.Message;
                }
                else if (sampleControl != null)
                {
                    string codePath = sampleControl.CodePath;
                    if (codePath != null)
                    {
                        try
                        {
                            System.Diagnostics.Debug.Assert(codePath.Contains(nodeName));
                            string path = "..\\" + codePath;
                            System.IO.StreamReader reader = new System.IO.StreamReader(path);
                            using (reader)
                            {
                                codeText = reader.ReadToEnd();
                                reader.Close();
                            }
                        }
                        catch (Exception ex)
                        {
                            codeText = "Exception parsing code text Exception=" + ex.ToString();
                        }
                    }
                    else
                        codeText = "Missing code file!";
                }
                else
                    codeText = "Missing sample control:  " + nodeName;
                codeText = codeText.Replace("<", "&lt;");
                codeText = codeText.Replace(">", "&gt;");
                codeText = codeText.Replace("\"", "&quot;");
                codeText = codeText.Replace(" ", "&nbsp;");
                codeText = codeText.Replace("\t", "&nbsp;&nbsp;&nbsp;&nbsp;");
                codeText = codeText.Replace("\r\n", "<br />");
                string language;
                if (exc != null)
                    language = "EXCEPTION!";
                else if (codeText.StartsWith("namespace"))
                    language = "C#";
                else
                    language = "VB.NET";
                string htmlText = "<html>";
                htmlText += "<body style=\"background-color: #6666cc\">";
                htmlText += "<table border=\"0\" cellpadding=\"4\" cellspacing=\"6\" width=\"100%\" style=\"background-color: Window\">";
                htmlText += "<tr><td style=\"color: white; background-color: #6666cc; font-size: medium; font-weight: bold\">" + nodeText + " Sample - " + language + "</td></tr>";
                htmlText += "<tr><td style=\"font-family: Courier New; font-size: x-small\">" + codeText + "</td></tr>";
                htmlText += "</table>";
                htmlText += "</body></html>";
                webBrowserDoc.DocumentText = htmlText;
            }
            else
            {
                System.Diagnostics.Debug.Assert(nodeName.Contains("Category"));
                Exception exc;
                ISampleCategory sampleCategory = sampleContainer.LoadSampleCategory(nodeName, out exc);
                if (sampleCategory != null)
                {
                    string docPath = Application.StartupPath + "\\" + sampleCategory.DocPath;
                    System.Uri uri = new System.Uri(docPath);
                    webBrowserDoc.Url = uri;
                }
                else
                {
                    string docText = "Missing sample category!";
                    string htmlText = "<html><body style=\"background-color: #6666cc\">";
                    htmlText += "<table border=\"0\" cellpadding=\"4\" cellspacing=\"6\" width=\"100%\" style=\"background-color: Window\">";
                    htmlText += "<tr><td style=\"color: white; background-color: #6666cc; font-size: medium; font-weight: bold\">" + nodeText + " Category</td></tr>";
                    htmlText += "<tr><td style=\"font-family: Courier New; font-size: x-small\">" + docText + "</td></tr>";
                    htmlText += "</table>";
                    htmlText += "</body></html>";
                    webBrowserDoc.DocumentText = htmlText;
                }
            }
        }
    }
}
