using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace SpreadsheetGearNavigator
{
    /// <summary>
    /// This class is only used to navigate the SpreadsheetGear Explorer.  
    /// </summary>
    public partial class SampleContainer : UserControl
    {
        private SampleManager _sampleManager;
        private ISampleControl _sampleControl;
        private ISampleCategory _sampleCategory;

        public SampleContainer()
        {
            InitializeComponent();
            _sampleManager = new SampleManager();
        }

        internal ISampleCategory CurrentCategory
        {
            get
            {
                return _sampleCategory;
            }
        }

        internal ISampleControl CurrentSample
        {
            get
            {
                return _sampleControl;
            }
        }

        internal ISampleCategory LoadSampleCategory(string typeName, out Exception exc)
        {
            exc = null;
            Controls.Clear();
            try
            {
                _sampleCategory = _sampleManager.GetSampleCategory(typeName);
            }
            catch (Exception e)
            {
                exc = e;
            }
            return _sampleCategory;
        }

        internal ISampleControl LoadSampleControl(string typeName, out Exception exc)
        {
            exc = null;
            Control sampleControl = null;
            Control curControl = Controls.Count > 0 ? Controls[0] : null;
            try
            {
                sampleControl = _sampleManager.GetSampleControl(typeName);
            }
            catch (Exception e)
            {
                exc = e;
            }
            if (sampleControl != null)
            {
                if (sampleControl.Dock != DockStyle.Fill)
                    sampleControl.Dock = DockStyle.Fill;
                if (curControl != null)
                {
                    this.MinimumSize = this.Size;
                    this.MaximumSize = this.Size;
                }
                Controls.Add(sampleControl);
            }
            if (curControl != null)
            {
                Controls.Remove(curControl);
                if (sampleControl != null)
                {
                    Size size = new Size(0, 0);
                    if (this.MinimumSize != size)
                        this.MinimumSize = size;
                    if (this.MaximumSize != size)
                        this.MaximumSize = size;
                    this.PerformLayout();
                }
            }
            _sampleControl = (ISampleControl)sampleControl;
            return _sampleControl;
        }

        internal void SetSampleControlAssembly(System.Reflection.Assembly assembly)
        {
            _sampleManager.SetSampleControlAssembly(assembly);
        }
    }
}
