using System;
using System.Collections.Generic;
using System.Reflection;
using System.Text;
using System.Windows.Forms;

namespace SpreadsheetGearNavigator
{
    /// <summary>
    /// This class is only used to navigate the SpreadsheetGear Explorer.  
    /// </summary>
    public class SampleManager
    {
        private List<ISampleCategory> _sampleCategories;
        private List<UserControl> _sampleControls;
        private Assembly _sampleControlAssembly;

        public SampleManager()
        {
            _sampleCategories = new List<ISampleCategory>();
            _sampleControls = new List<UserControl>();
        }

        public ISampleCategory FindCategory(System.Type type)
        {
            for (int i = 0; i < _sampleCategories.Count; i++)
            {
                ISampleCategory sample = _sampleCategories[i];
                if (sample.GetType() == type)
                    return sample;
            }
            return null;
        }

        public UserControl FindControl(System.Type type)
        {
            for (int i = 0; i < _sampleControls.Count; i++)
            {
                UserControl sample = _sampleControls[i];
                if (sample.GetType() == type)
                    return sample;
            }
            return null;
        }

        public ISampleCategory GetSampleCategory(string name)
        {
            ISampleCategory sampleCategory = null;
            if (name != null)
            {
                string typeName = "SpreadsheetGearNavigator." + name;
                System.Type type = System.Type.GetType(typeName);
                sampleCategory = FindCategory(type);
                if (sampleCategory == null)
                {
                    ConstructorInfo[] constructorInfos = type.GetConstructors();
                    System.Diagnostics.Debug.Assert(constructorInfos.Length == 1);
                    sampleCategory = (ISampleCategory)constructorInfos[0].Invoke(null);
                    if (sampleCategory != null)
                        _sampleCategories.Add(sampleCategory);
                }
            }
            return sampleCategory;
        }

        public UserControl GetSampleControl(string name)
        {
            UserControl sampleControl = null;
            if (name != null)
            {
                string typeName = "SpreadsheetGearExplorer." + name;
                System.Type type = _sampleControlAssembly.GetType(typeName);
                if (type != null)
                {
                    sampleControl = FindControl(type);
                    if (sampleControl == null)
                    {
                        ConstructorInfo[] constructorInfos = type.GetConstructors();
                        System.Diagnostics.Debug.Assert(constructorInfos.Length == 1);
                        sampleControl = (UserControl)constructorInfos[0].Invoke(null);
                        if (sampleControl != null)
                            _sampleControls.Add(sampleControl);
                    }
                }
            }
            return sampleControl;
        }

        public void SetSampleControlAssembly(System.Reflection.Assembly assembly)
        {
            _sampleControlAssembly = assembly;
            try
            {
                GetSampleCategory("SpreadsheetGearExplorerCategory");
                GetSampleControl("ActiveWorkbookSample");
            }
            catch
            {
            }
        }
    }

    public interface ISampleControl
    {
        string CodePath
        {
            get;
        }
    }

    public interface ISampleCategory
    {
        string DocPath
        {
            get;
        }
    }

    public class SpreadsheetGearExplorerCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\SGExplorerPage.html";
            }
        }
    }

    public class WorkbookViewCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\WorkbookViewPage.html";
            }
        }
    }

    public class WorkbookViewDisplayOptionsCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\WorkbookViewDisplayOptionsPage.html";
            }
        }
    }

    public class WorkbookViewEventsCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\WorkbookViewEventsPage.html";
            }
        }
    }

    public class RangeCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\RangePage.html";
            }
        }
    }

    public class ChartingCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\ChartingPage.html";
            }
        }
    }

    public class ShapesCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\ShapesPage.html";
            }
        }
    }

    public class ControlsCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\ControlsPage.html";
            }
        }
    }

    public class ReportingCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\ReportingPage.html";
            }
        }
    }

    public class CalculationsCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\CalculationsPage.html";
            }
        }
    }

    public class AdvancedCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\AdvancedPage.html";
            }
        }
    }

    public class DataGridCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\DataGridPage.html";
            }
        }
    }

    public class CommandManagerCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\CommandManagerPage.html";
            }
        }
    }

    public class PrintingCategory : ISampleCategory
    {
        string ISampleCategory.DocPath
        {
            get
            {
                return "Documentation\\PrintingPage.html";
            }
        }
    }
}
