Partial Class BasicChartSample

    Private Sub ShowColumnChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing defined name.
            Dim source As SpreadsheetGear.IRange = _
                WorkbookView.ActiveWorkbook.Names("RegionalSales").RefersToRange

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to a clustered column.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.ColumnClustered

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Regional Sales for 2007"
            chart.ChartTitle.Font.Size = 12

            ' Get a reference to the value axis and set the gridline dash style.
            Dim valueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)
            valueAxis.MajorGridlines.Format.Line.DashStyle = _
                SpreadsheetGear.Shapes.LineDashStyle.Dash
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowLineChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing defined name.
            Dim source As SpreadsheetGear.IRange = _
                WorkbookView.ActiveWorkbook.Names("TotalByRegion").RefersToRange

            ' Set the chart's source data range, plotting series in rows.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Rows)

            ' Set the chart type to a line chart with markers.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.LineMarkers

            ' Get a reference to the single total series.
            Dim seriesTotal As SpreadsheetGear.Charts.ISeries = chart.SeriesCollection(0)

            ' Add category axis labels by using an existing defined name.
            seriesTotal.XValues = "=Regions"

            ' Add series data labels and position them above the data points.
            seriesTotal.HasDataLabels = True
            seriesTotal.DataLabels.Position = SpreadsheetGear.Charts.DataLabelPosition.Above

            ' Hide the legend.
            chart.HasLegend = False

            ' Hide the major gridlines on the value axis.
            chart.Axes(SpreadsheetGear.Charts.AxisType.Value).HasMajorGridlines = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Total Sales by Region"
            chart.ChartTitle.Font.Size = 12
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowPieChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing defined name.
            Dim source As SpreadsheetGear.IRange = _
                WorkbookView.ActiveWorkbook.Names("TotalByQuarter").RefersToRange

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to a pie chart.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.Pie

            ' Get a reference to the single total series.
            Dim seriesTotal As SpreadsheetGear.Charts.ISeries = chart.SeriesCollection(0)

            ' Add category labels by using an existing defined name.
            seriesTotal.XValues = "=Quarters"

            ' Add series data labels and change to show percentage only.
            seriesTotal.HasDataLabels = True
            seriesTotal.DataLabels.ShowPercentage = True
            seriesTotal.DataLabels.ShowValue = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Percentage of Sales by Quarter"
            chart.ChartTitle.Font.Size = 12
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowBarChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing defined name.
            Dim source As SpreadsheetGear.IRange = _
                WorkbookView.ActiveWorkbook.Names("RegionalSales").RefersToRange

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to a stacked bar.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.BarStacked

            ' Set the distance between bars as a percentage of the bar width.
            chart.ChartGroups(0).GapWidth = 50

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Combined Sales by Quarter"
            chart.ChartTitle.Font.Size = 12

            ' Get a reference to the value axis and set the gridline dash style.
            Dim valueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)
            valueAxis.MajorGridlines.Format.Line.DashStyle = _
                SpreadsheetGear.Shapes.LineDashStyle.Dash
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowAreaChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing defined name.
            Dim source As SpreadsheetGear.IRange = _
                WorkbookView.ActiveWorkbook.Names("TotalByQuarter").RefersToRange

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to an area chart.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.Area

            ' Get a reference to the single total series.
            Dim seriesTotal As SpreadsheetGear.Charts.ISeries = chart.SeriesCollection(0)

            ' Add category axis labels by using an existing defined name.
            seriesTotal.XValues = "=Quarters"

            ' Change the theme color of the total series.
            seriesTotal.Format.Fill.ForeColor.ThemeColor = SpreadsheetGear.Themes.ColorSchemeIndex.Accent4

            ' Hide the legend.
            chart.HasLegend = False

            ' Hide the major gridlines on the value axis.
            chart.Axes(SpreadsheetGear.Charts.AxisType.Value).HasMajorGridlines = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Total Sales by Quarter"
            chart.ChartTitle.Font.Size = 12
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Function AddChart(ByVal workbookView As SpreadsheetGear.Windows.Forms.WorkbookView) As SpreadsheetGear.Charts.IChart

        ' Get a reference to the worksheet window info and shapes collection.
        Dim worksheet As SpreadsheetGear.IWorksheet = workbookView.ActiveWorksheet
        Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo
        Dim shapes As SpreadsheetGear.Shapes.IShapes = worksheet.Shapes

        ' Delete any existing shapes.
        While shapes.Count <> 0
            shapes(0).Delete()
        End While

        ' Add a chart to the worksheet's shape collection.
        ' NOTE: Calculate the coordinates of the chart by converting row and column
        '       coordinates to points.  Use fractional row and column values to get 
        '       coordinates anywhere in between row and column boundaries.
        Dim left As Double = windowInfo.ColumnToPoints(0.15)
        Dim top As Double = windowInfo.RowToPoints(0.5)
        Dim right As Double = windowInfo.ColumnToPoints(5.85)
        Dim bottom As Double = windowInfo.RowToPoints(13.5)
        Dim chart As SpreadsheetGear.Charts.IChart = _
            shapes.AddChart(left, top, right - left, bottom - top).Chart

        ' Return the chart.
        Return chart

    End Function 'AddChart
End Class
