Partial Class BubbleChartSample

    Private Sub AddBubbleChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet, window info, and cells.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo
            Dim cells As SpreadsheetGear.IRange = worksheet.Cells

            ' Add a chart to the worksheet's shape collection.
            ' NOTE: Calculate the coordinates of the chart by converting row and column
            '       coordinates to points.  Use fractional row and column values to get 
            '       coordinates anywhere in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(0.15)
            Dim top As Double = windowInfo.RowToPoints(0.5)
            Dim right As Double = windowInfo.ColumnToPoints(5.85)
            Dim bottom As Double = windowInfo.RowToPoints(13.5)
            Dim chart As SpreadsheetGear.Charts.IChart = _
                worksheet.Shapes.AddChart(left, top, right - left, bottom - top).Chart

            ' Set the chart type to bubble.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.Bubble

            ' Get the chart's source data range.
            Dim source As SpreadsheetGear.IRange = cells("G3:J6")

            ' for each row in the data range...
            Dim row As Integer
            For row = 0 To source.RowCount - 1
                ' Add a series to the chart's series collection.
                Dim series As SpreadsheetGear.Charts.ISeries = chart.SeriesCollection.Add()

                ' Set the series name, x values, y values, and bubble size values.
                series.Name = "=" + source(row, 0).Address
                series.XValues = source(row, 1)
                series.Values = source(row, 2)
                series.BubbleSizes = source(row, 3)
            Next row

            ' Get a reference to the x value axis, add a title, and link the title to a cell.
            Dim xValueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Category)
            xValueAxis.HasTitle = True
            xValueAxis.AxisTitle.Text = "=H2"

            ' Get a reference to the y value axis, add a title, and link the title to a cell.
            Dim yValueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)
            yValueAxis.HasTitle = True
            yValueAxis.AxisTitle.Text = "=I2"

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Estimated Return on Investment"
            chart.ChartTitle.Font.Size = 12
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
