Partial Class GalleryChartSample

    Private Sub DisplayImage()
        ' If the picture box already has an image...
        Dim curImage As System.Drawing.Image = PictureBox.Image
        If Not (curImage Is Nothing) Then
            ' Dispose the image to free resources.
            PictureBox.Image = Nothing
            curImage.Dispose()
        End If

        ' Get the currently selected category.
        Dim selectedCategory As String = ListBoxCategory.Text

        ' Get the currently selected type.
        Dim selectedType As String = ListBoxType.Text

        ' Get the worksheet based on the selected category name.
        Dim worksheet As SpreadsheetGear.IWorksheet = Workbook.Worksheets(selectedCategory)

        ' Get the shape based on the selected type.
        Dim shape As SpreadsheetGear.Shapes.IShape = worksheet.Shapes(selectedType)

        ' Create the SpreadsheetGear Image class...
        Dim image As New SpreadsheetGear.Drawing.Image(shape)

        ' Get a new bitmap image of the represented shape.
        ' NOTE: The default PixelFormat will be PixelFormat.Format32bppArgb
        '       Use the overloaded GetBitmap() method to return another format.
        Dim bitmap As System.Drawing.Bitmap = image.GetBitmap()

        ' Set the new image to display in the picture box.
        PictureBox.Image = bitmap
    End Sub

    Private Sub FillCategoryList()
        ' Clear the category list
        ListBoxCategory.Items.Clear()

        ' Dynamically build the category list using worksheet names.
        Dim worksheet As SpreadsheetGear.IWorksheet
        For Each worksheet In Workbook.Worksheets
            ListBoxCategory.Items.Add(worksheet.Name)
        Next worksheet

        ' Select the stock category.
        ListBoxCategory.SelectedIndex = 6

        ' Assure that all items are displayed in each list.
        Dim height As Integer = System.Math.Max( _
            ListBoxCategory.PreferredHeight, ListBoxType.PreferredHeight)
        ListBoxCategory.Height = height
        ListBoxType.Height = height
    End Sub

    Private Sub FillTypeList()
        ' The index of the selected type.
        Dim selectedIndex As Integer

        ' If we are initializing the sample...
        If ListBoxType.Items.Count = 0 Then
            ' Set the selected index to a specific type.
            selectedIndex = 3
        Else
            ' Set the selected index to the first type.
            selectedIndex = 0

            ' Clear the type list.
            ListBoxType.Items.Clear()
        End If

        ' Get the currently selected category.
        Dim selectedCategory As String = ListBoxCategory.Text

        ' Get the worksheet based on the selected category name.
        Dim worksheet As SpreadsheetGear.IWorksheet = Workbook.Worksheets(selectedCategory)

        ' Dynamically build the type list using shape names.
        Dim shape As SpreadsheetGear.Shapes.IShape
        For Each shape In worksheet.Shapes
            ListBoxType.Items.Add(shape.Name)
        Next shape

        ' Set the index of the selected type.
        ListBoxType.SelectedIndex = selectedIndex
    End Sub

End Class
