Partial Class GanttChartSample

    Private Sub AddGanttChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet, window info, and cells.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo
            Dim cells As SpreadsheetGear.IRange = worksheet.Cells

            ' Load row titles using multiple cell text reference and iteration.
            Dim task As Integer = 1
            Dim cell As SpreadsheetGear.IRange
            For Each cell In cells("G2:G7")
                cell.Formula = "Task " + task.ToString()
                task = task + 1
            Next cell
            
            ' Start with zero and use formulas to calculate each additional start value.
            cells("H2").Formula = "0"
            cells("H3:H7").Formula = "=H2+I2"
            
            ' Load random duration values
            cells("I2:I7").Formula = "=INT(RAND() * 10) + 2"

            ' Add a chart to the worksheet's shape collection.
            ' NOTE: Calculate the coordinates of the chart by converting row and column
            '       coordinates to points.  Use fractional row and column values to get 
            '       coordinates anywhere in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(0.15)
            Dim top As Double = windowInfo.RowToPoints(0.5)
            Dim right As Double = windowInfo.ColumnToPoints(5.85)
            Dim bottom As Double = windowInfo.RowToPoints(13.5)
            Dim chart As SpreadsheetGear.Charts.IChart = _
                worksheet.Shapes.AddChart(left, top, right - left, bottom - top).Chart

            ' Set the chart's source data range, plotting series in columns.
            Dim source As SpreadsheetGear.IRange = cells("G2:I7")
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to stacked bar to simulate a gantt chart.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.BarStacked

            ' Set the distance between bars as a percentage of the bar width.
            chart.ChartGroups(0).GapWidth = 100

            ' Hide the first (Start) series values by setting the fill to none.
            chart.SeriesCollection(0).Format.Fill.Visible = False

            ' Change the theme color of the second (Duration) series.
            chart.SeriesCollection(1).Format.Fill.ForeColor.ThemeColor = _
                SpreadsheetGear.Themes.ColorSchemeIndex.Accent3

            ' Reverse the category axis so that values are shown top to bottom.
            chart.Axes(SpreadsheetGear.Charts.AxisType.Category).ReversePlotOrder = True

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Estimated Days To Completion"
            chart.ChartTitle.Font.Size = 12

            ' Delete the legend.
            chart.HasLegend = False
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
