Partial Class RadarChartSample

    Private Sub AddRadarChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet, window info, and cells.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo
            Dim cells As SpreadsheetGear.IRange = worksheet.Cells

            ' Add a chart to the worksheet's shape collection.
            ' NOTE: Calculate the coordinates of the chart by converting row and column
            '       coordinates to points. Use fractional row and column values to get 
            '       coordinates anywhere in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(0.15)
            Dim top As Double = windowInfo.RowToPoints(0.5)
            Dim right As Double = windowInfo.ColumnToPoints(5.85)
            Dim bottom As Double = windowInfo.RowToPoints(13.5)
            Dim chart As SpreadsheetGear.Charts.IChart = _
                worksheet.Shapes.AddChart(left, top, right - left, bottom - top).Chart

            ' Get the source data range from an existing defined name.
            Dim source As SpreadsheetGear.IRange = _
                WorkbookView.ActiveWorkbook.Names("Maintenance").RefersToRange

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to filled radar.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.RadarFilled

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "Seasonal Maintenance Costs"
            chart.ChartTitle.Font.Size = 12
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
