Partial Class StockChartSample

    Private Sub ShowHLCChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing XML File.
            Dim source As SpreadsheetGear.IRange = _
                GetSourceData(WorkbookView, "stockhlc.xml")

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to a high-low-close stock chart.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.StockHLC

            ' Get a reference to the primary category axis.
            Dim categoryAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Category)

            ' Change the primary category axis to always use a category scale.
            categoryAxis.CategoryType = _
                SpreadsheetGear.Charts.CategoryType.CategoryScale

            ' Set the label frequency of the primary category axis.
            categoryAxis.TickLabelSpacing = 7

            ' Get a reference to the primary value axis.
            Dim valueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)

            ' Set the min, max, and major units of the primary value axis.
            valueAxis.MinimumScale = 80
            valueAxis.MaximumScale = 130
            valueAxis.MajorUnit = 10

            ' Hide the major gridlines on the primary value axis.
            valueAxis.HasMajorGridlines = False

            ' Delete the legend.
            chart.HasLegend = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "ABC Company (High-Low-Close)"
            chart.ChartTitle.Font.Size = 10
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowOHLCChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing XML File.
            Dim source As SpreadsheetGear.IRange = _
                GetSourceData(WorkbookView, "stockohlc.xml")

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to an open-high-low-close stock chart.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.StockOHLC

            ' Get a reference to the first and only chart group.
            Dim chartGroup As SpreadsheetGear.Charts.IChartGroup = chart.ChartGroups(0)

            ' Change the fill color of the down bars.
            chartGroup.DownBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Red

            ' Change the fill color of the up bars.
            chartGroup.UpBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Green

            ' Get a reference to the primary category axis.
            Dim categoryAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Category)

            ' Change the primary category axis to always use a category scale.
            categoryAxis.CategoryType = _
                SpreadsheetGear.Charts.CategoryType.CategoryScale

            ' Set the label frequency of the primary category axis.
            categoryAxis.TickLabelSpacing = 7

            ' Get a reference to the primary value axis.
            Dim valueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)

            ' Set the min, max, and major units of the primary value axis.
            valueAxis.MinimumScale = 80
            valueAxis.MaximumScale = 130
            valueAxis.MajorUnit = 10

            ' Hide the major gridlines on the primary value axis.
            valueAxis.HasMajorGridlines = False

            ' Delete the legend.
            chart.HasLegend = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "ABC Company (Open-High-Low-Close)"
            chart.ChartTitle.Font.Size = 10
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowVHLCChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing XML File.
            Dim source As SpreadsheetGear.IRange = _
                GetSourceData(WorkbookView, "stockvhlc.xml")

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to a volume-high-low-close stock chart.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.StockVHLC

            ' Get a reference to the first chart group used for the volume series.
            Dim volumeGroup As SpreadsheetGear.Charts.IChartGroup = chart.ChartGroups(0)

            ' Increase the volume series bar width by decreasing the gap width.
            volumeGroup.GapWidth = 75

            ' Get a reference to the primary category axis.
            Dim categoryAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Category)

            ' Change the primary category axis to always use a category scale.
            categoryAxis.CategoryType = _
                SpreadsheetGear.Charts.CategoryType.CategoryScale

            ' Set the label frequency of the primary category axis.
            categoryAxis.TickLabelSpacing = 7

            ' Get a reference to the primary value axis.
            Dim valueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)

            ' Set the min, max, and major units of the primary value axis.
            valueAxis.MinimumScale = 0
            valueAxis.MaximumScale = 130000
            valueAxis.MajorUnit = 26000

            ' Hide the major gridlines on the primary value axis.
            valueAxis.HasMajorGridlines = False

            ' Get a reference to the secondary value axis.
            valueAxis = chart.Axes( _
                SpreadsheetGear.Charts.AxisType.Value, _
                SpreadsheetGear.Charts.AxisGroup.Secondary)

            ' Set the min, max, and major units of the secondary value axis.
            valueAxis.MinimumScale = 0
            valueAxis.MaximumScale = 130
            valueAxis.MajorUnit = 26

            ' Hide the major gridlines on the secondary value axis.
            valueAxis.HasMajorGridlines = False

            ' Delete the legend.
            chart.HasLegend = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "ABC Company (Volume-High-Low-Close)"
            chart.ChartTitle.Font.Size = 10
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowVOHLCChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a new chart.
            Dim chart As SpreadsheetGear.Charts.IChart = AddChart(WorkbookView)

            ' Get the source data range from an existing XML File.
            Dim source As SpreadsheetGear.IRange = _
                GetSourceData(WorkbookView, "stockvohlc.xml")

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(source, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type to a volume-open-high-low-close stock chart.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.StockVOHLC

            ' Get a reference to the first chart group used for volume series.
            Dim volumeGroup As SpreadsheetGear.Charts.IChartGroup = chart.ChartGroups(0)

            ' Increase the volume series bar width by decreasing the gap width.
            volumeGroup.GapWidth = 75

            ' Get a reference to the second chart group used for stock values.
            Dim stockGroup As SpreadsheetGear.Charts.IChartGroup = chart.ChartGroups(1)

            ' Change the fill color of the down bars.
            stockGroup.DownBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Red

            ' Change the fill color of the up bars.
            stockGroup.UpBars.Format.Fill.ForeColor.RGB = SpreadsheetGear.Colors.Green

            ' Get a reference to the primary category axis.
            Dim categoryAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Category)

            ' Change the primary category axis to always use a category scale.
            categoryAxis.CategoryType = _
                SpreadsheetGear.Charts.CategoryType.CategoryScale

            ' Set the label frequency of the primary category axis.
            categoryAxis.TickLabelSpacing = 7

            ' Get a reference to the primary value axis.
            Dim valueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)

            ' Set the min, max, and major units of the primary value axis.
            valueAxis.MinimumScale = 0
            valueAxis.MaximumScale = 130000
            valueAxis.MajorUnit = 26000

            ' Hide the major gridlines on the primary value axis.
            valueAxis.HasMajorGridlines = False

            ' Get a reference to the secondary value axis.
            valueAxis = chart.Axes( _
                SpreadsheetGear.Charts.AxisType.Value, _
                SpreadsheetGear.Charts.AxisGroup.Secondary)

            ' Set the min, max, and major units of the secondary value axis.
            valueAxis.MinimumScale = 0
            valueAxis.MaximumScale = 130
            valueAxis.MajorUnit = 26

            ' Hide the major gridlines on the secondary value axis.
            valueAxis.HasMajorGridlines = False

            ' Delete the legend.
            chart.HasLegend = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "ABC Company (Volume-Open-High-Low-Close)"
            chart.ChartTitle.Font.Size = 10
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Function AddChart(ByVal workbookView As SpreadsheetGear.Windows.Forms.WorkbookView) As SpreadsheetGear.Charts.IChart

        ' Get a reference to the worksheet window info and shapes collection.
        Dim worksheet As SpreadsheetGear.IWorksheet = workbookView.ActiveWorksheet
        Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo
        Dim shapes As SpreadsheetGear.Shapes.IShapes = worksheet.Shapes

        ' Delete any existing shapes.
        While shapes.Count <> 0
            shapes(0).Delete()
        End While

        ' Add a chart to the worksheet's shape collection.
        ' NOTE: Calculate the coordinates of the chart by converting row and column
        '       coordinates to points.  Use fractional row and column values to get 
        '       coordinates anywhere in between row and column boundaries.
        Dim left As Double = windowInfo.ColumnToPoints(0.15)
        Dim top As Double = windowInfo.RowToPoints(0.5)
        Dim right As Double = windowInfo.ColumnToPoints(5.85)
        Dim bottom As Double = windowInfo.RowToPoints(13.5)
        Dim chart As SpreadsheetGear.Charts.IChart = _
            shapes.AddChart(left, top, right - left, bottom - top).Chart

        ' Return the chart.
        Return chart

    End Function 'AddChart

    Private Function GetSourceData(ByVal workbookView As SpreadsheetGear.Windows.Forms.WorkbookView, ByVal xmlFile As String) As SpreadsheetGear.IRange

        ' Get a reference to the active worksheet.
        Dim worksheet As SpreadsheetGear.IWorksheet = workbookView.ActiveWorksheet

        ' Clear any existing worksheet data.
        worksheet.Cells.Clear()

        ' Load a data set from an XML file.
        Dim dataset As New System.Data.DataSet()
        dataset.ReadXml(xmlFile)

        ' Get a reference to the first and only data table.
        Dim datatable As System.Data.DataTable = dataset.Tables(0)

        ' Get a reference to a range matching the size of the data table.
        Dim row1 As Integer = 1
        Dim col1 As Integer = 6
        Dim row2 As Integer = row1 + datatable.Rows.Count
        Dim col2 As Integer = col1 + datatable.Columns.Count - 1
        Dim source As SpreadsheetGear.IRange = worksheet.Cells(row1, col1, row2, col2)

        ' Copy the data table to the range.
        source.CopyFromDataTable(datatable, SpreadsheetGear.Data.SetDataFlags.None)

        ' return the range.
        Return source

    End Function 'GetSourceData
End Class
