Partial Class XYScatterChartSample

    Private Sub AddXYScatterChart(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet, window info, and cells.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo
            Dim cells As SpreadsheetGear.IRange = worksheet.Cells

            ' Get the chart's source data range and add some sample data.
            cells("G2:J30").Formula = "=INT(RAND() * 500) + 150"

            ' Add a chart to the worksheet's shape collection.
            ' NOTE: Calculate the coordinates of the chart by converting row and column
            '       coordinates to points.  Use fractional row and column values to get 
            '       coordinates anywhere in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(0.15)
            Dim top As Double = windowInfo.RowToPoints(0.5)
            Dim right As Double = windowInfo.ColumnToPoints(5.85)
            Dim bottom As Double = windowInfo.RowToPoints(13.5)
            Dim chart As SpreadsheetGear.Charts.IChart = _
                worksheet.Shapes.AddChart(left, top, right - left, bottom - top).Chart

            ' Add a series and link x and y values to the source data range.
            Dim series1 As SpreadsheetGear.Charts.ISeries = chart.SeriesCollection.Add()
            series1.XValues = "=G2:G30"
            series1.Values = "=H2:H30"

            ' Add a second series and link x an y values to the source data range.
            Dim series2 As SpreadsheetGear.Charts.ISeries = chart.SeriesCollection.Add()
            series2.XValues = "=I2:I30"
            series2.Values = "=J2:J30"

            ' Set the chart type to XYScatter.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.XYScatter

            ' Get a reference to the x value axis, add a title, and link the title to a cell.
            Dim xValueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Category)
            xValueAxis.HasTitle = True
            xValueAxis.AxisTitle.Text = "X Value Axis"

            ' Get a reference to the y value axis, add a title, and link the title to a cell.
            Dim yValueAxis As SpreadsheetGear.Charts.IAxis = _
                chart.Axes(SpreadsheetGear.Charts.AxisType.Value)
            yValueAxis.HasTitle = True
            yValueAxis.AxisTitle.Text = "Y Value Axis"

            ' Delete the major gridlines from the y value axis.
            yValueAxis.HasMajorGridlines = False

            ' Delete the legend.
            chart.HasLegend = False

            ' Add a chart title and change the font size.
            chart.HasTitle = True
            chart.ChartTitle.Text = "XY Scatter Plot"
            chart.ChartTitle.Font.Size = 12
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
