Partial Class SimpleCommandSample

    Private Sub ExecuteCommand(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Create an instance of the simple command.
            Dim command As New CommandSimple(WorkbookView)

            ' Execute the command.
            WorkbookView.ActiveCommandManager.Execute(command)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub UndoCommand(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Undo the last undoable command.
            WorkbookView.ActiveCommandManager.Undo()
        Catch exc As System.Exception
            System.Windows.Forms.MessageBox.Show(exc.Message, "SpreadsheetGear")
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Class CommandSimple
        Inherits SpreadsheetGear.Commands.Command
        Private workbookView As SpreadsheetGear.Windows.Forms.WorkbookView
        Private saveDisplayGridlines As Boolean

        Public Sub New(ByVal workbookView As SpreadsheetGear.Windows.Forms.WorkbookView)
            MyBase.New(workbookView.ActiveWorkbook)
            Me.workbookView = workbookView
        End Sub

        Public Overrides ReadOnly Property DisplayText() As String
            Get
                ' Text displayed in Undo menu.
                Return "Toggle Display Gridlines"
            End Get
        End Property

        Public Overrides ReadOnly Property UndoSupport() As SpreadsheetGear.Commands.CommandUndoSupport
            Get
                ' Undo is fully supported.
                Return SpreadsheetGear.Commands.CommandUndoSupport.Full
            End Get
        End Property

        Protected Overrides Function Execute() As Boolean
            ' Execute the command - we won't save state since we're
            ' just toggling a boolean value.
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = workbookView.ActiveWorksheetWindowInfo
            saveDisplayGridlines = windowInfo.DisplayGridlines
            windowInfo.DisplayGridlines = Not saveDisplayGridlines
            Return True
        End Function

        Protected Overrides Function Undo() As Boolean
            ' Undo the command.
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = workbookView.ActiveWorksheetWindowInfo
            windowInfo.DisplayGridlines = saveDisplayGridlines
            Return True
        End Function
    End Class

End Class
