Partial Class ButtonSample

    Private Sub AddButton(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet and worksheet window info.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo

            ' Calculate the left, top, width and height of the button by 
            ' converting row and column coordinates to points.  Use fractional 
            ' values to get coordinates in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(0.5)
            Dim top As Double = windowInfo.RowToPoints(0.5)
            Dim right As Double = windowInfo.ColumnToPoints(3.5)
            Dim bottom As Double = windowInfo.RowToPoints(2.5)
            Dim width As Double = right - left
            Dim height As Double = bottom - top

            ' Add the first button using the calculated bounds.
            Dim shape As SpreadsheetGear.Shapes.IShape = worksheet.Shapes.AddFormControl( _
                SpreadsheetGear.Shapes.FormControlType.ButtonControl, left, top, width, height)

            ' Give the first button a name (used to tell the two buttons apart later).
            shape.Name = "ChangeB4"

            ' Set the text of the first button.
            shape.TextFrame.Characters.Text = "Click Here to Change B4"

            ' Calculate the position of the second button.
            left = windowInfo.ColumnToPoints(0.5)
            top = windowInfo.RowToPoints(5.5)
            right = windowInfo.ColumnToPoints(3.5)
            bottom = windowInfo.RowToPoints(7.5)
            width = right - left
            height = bottom - top

            ' Add the second button using the calculated bounds.
            shape = worksheet.Shapes.AddFormControl( _
                SpreadsheetGear.Shapes.FormControlType.ButtonControl, left, top, width, height)

            ' Give the second button a name (used to tell the two buttons apart later).
            shape.Name = "ChangeB9"

            ' Set the text of the second button.
            shape.TextFrame.Characters.Text = "Click Here to Change B9"
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub WorkbookView_ShapeAction(ByVal sender As System.Object, ByVal e As SpreadsheetGear.Windows.Forms.ShapeActionEventArgs) Handles WorkbookView.ShapeAction

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Handle the WorkbookView.ShapeAction event in order
            ' to hook into the button's Click event.
            Select Case e.ShapeActionType
                Case SpreadsheetGear.Windows.Forms.ShapeActionType.Click
                    ' Get a reference to a cell.
                    Dim cell As SpreadsheetGear.IRange

                    ' Is it the first button?
                    If e.Shape.Name.Equals("ChangeB4") Then
                        cell = WorkbookView.ActiveWorksheet.Cells("B4")
                    Else
                        ' Assume there are only two buttons
                        cell = WorkbookView.ActiveWorksheet.Cells("B9")
                    End If

                    ' Add text to the cell.
                    cell.Value = "SpreadsheetGear for .NET"

                    ' Set various font options.
                    Dim font As SpreadsheetGear.IFont = cell.Font
                    font.Name = "Times New Roman"
                    font.Size = 18
                    font.Bold = True
                    font.Color = SpreadsheetGear.Colors.SlateBlue
            End Select
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
