Partial Class ListBoxSample

    Private Sub AddListBox(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet and worksheet window info.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo

            ' Calculate the left, top, width and height of the listbox by 
            ' converting row and column coordinates to points.  Use fractional 
            ' values to get coordinates in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(1.1)
            Dim top As Double = windowInfo.RowToPoints(1.1)
            Dim right As Double = windowInfo.ColumnToPoints(2.9)
            Dim bottom As Double = windowInfo.RowToPoints(8.9)
            Dim width As Double = right - left
            Dim height As Double = bottom - top

            ' Add the listbox using the calculated bounds.
            Dim shape As SpreadsheetGear.Shapes.IShape = worksheet.Shapes.AddFormControl( _
                SpreadsheetGear.Shapes.FormControlType.ListBox, left, top, width, height)

            ' Get a reference to the control format.
            Dim controlFormat As SpreadsheetGear.Shapes.IControlFormat = shape.ControlFormat

            ' Fill the listbox with a range of existing values.
            controlFormat.ListFillRange = "A50:A61"

            ' Link the listbox to cell A2.
            controlFormat.LinkedCell = "A2"

            ' Select the first item in the list.
            controlFormat.ListIndex = 0
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
