Partial Class SpinnerSample

    Private Sub AddSpinner(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet and worksheet window info.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo

            ' Calculate the left, top, width and height of the spinner by 
            ' converting row and column coordinates to points.  Use fractional 
            ' values to get coordinates in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(1.1)
            Dim top As Double = windowInfo.RowToPoints(1.4)
            Dim right As Double = windowInfo.ColumnToPoints(1.9)
            Dim bottom As Double = windowInfo.RowToPoints(2.6)
            Dim width As Double = right - left
            Dim height As Double = bottom - top

            ' Add the spinner using the calculated bounds.
            Dim shape As SpreadsheetGear.Shapes.IShape = worksheet.Shapes.AddFormControl( _
                SpreadsheetGear.Shapes.FormControlType.Spinner, left, top, width, height)

            ' Get a reference to the control format.
            Dim controlFormat As SpreadsheetGear.Shapes.IControlFormat = shape.ControlFormat

            ' Link the spinner to cell A2.
            controlFormat.LinkedCell = "A2"

            ' Set the spinner minimum, maximum and interval.
            controlFormat.Min = 0
            controlFormat.Max = 100
            controlFormat.SmallChange = 10
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
