Partial Class AdvancedPrintingSample

    Private Sub Print(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Create a workbook print document.
            Dim document As SpreadsheetGear.Drawing.Printing.WorkbookPrintDocument = _
                CreatePrintDocument(WorkbookView.ActiveWorkbook)

            Using document
                ' Create a print dialog.
                Dim dialog As New System.Windows.Forms.PrintDialog()

                ' Set the print dialogs print document.
                dialog.Document = document

                ' Work around this issue
                ' http//stackoverflow.com/questions/6385844/printdialog-showdialog-Not-showing-the-print-dialog-in-windows-7-with-64-bit

                If (System.IntPtr.Size > 4) Then
                    dialog.UseEXDialog = True
                End If

                ' Show the print dialog and check the return status...
                If dialog.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK Then
                    ' Print the document.
                    document.Print()
                End If
            End Using
        Catch exc As Exception
            System.Windows.Forms.MessageBox.Show(Me, exc.Message, "SpreadsheetGear Explorer", _
                System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Error)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub CustomPrintPreview(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Create a workbook print document.
            Dim document As SpreadsheetGear.Drawing.Printing.WorkbookPrintDocument = _
                CreatePrintDocument(WorkbookView.ActiveWorkbook)

            Using document
                ' Create a custom print preview dialog.
                Dim dialog As New CustomPrintPreviewDialog()

                ' Set the print preview dialogs print document.
                dialog.Document = document

                ' Show the print preview dialog.
                dialog.ShowDialog(Me)
            End Using
        Catch exc As Exception
            System.Windows.Forms.MessageBox.Show(Me, exc.Message, "SpreadsheetGear Explorer", _
                System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Error)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Function CreatePrintDocument(ByVal workbook As SpreadsheetGear.IWorkbook) As SpreadsheetGear.Drawing.Printing.WorkbookPrintDocument
        ' Create an empty printable list.
        Dim printables As New System.Collections.Generic.List(Of SpreadsheetGear.IPrintable)()

        ' If the range option is selected...
        If CheckBoxRange.Checked Then
            ' Get a reference to a range from an existing defined name.
            Dim range As SpreadsheetGear.IRange = workbook.Worksheets(0).Cells("West")

            ' Add the range to the printable list.
            printables.Add(range)
        End If

        ' If the chart option is selected...
        If CheckBoxChart.Checked Then
            ' Get a reference to a chart.
            Dim chart As SpreadsheetGear.Charts.IChart = workbook.Worksheets(0).Shapes("Chart 1").Chart

            ' Add the chart to the printable list.
            printables.Add(chart)
        End If

        ' Create a workbook print document.
        Dim document As New SpreadsheetGear.Drawing.Printing.WorkbookPrintDocument(printables)

        ' Return the workbook print document.
        Return document
    End Function

End Class
