
' Provides a custom print preview form.
Public Class CustomPrintPreviewDialog
    Private pagecount As Integer

    ' Gets or sets a value indicating the document to preview.
    Public Property Document() As System.Drawing.Printing.PrintDocument
        Get
            Return PrintPreviewControl.Document
        End Get
        Set(ByVal value As System.Drawing.Printing.PrintDocument)
            PrintPreviewControl.Document = value
            AddHandler value.BeginPrint, AddressOf PrintDocument_BeginPrint
            AddHandler value.EndPrint, AddressOf PrintDocument_EndPrint
            AddHandler value.PrintPage, AddressOf PrintDocument_PrintPage
        End Set
    End Property

    ' Overridden to allow for specialized processing of key events.
    Protected Overloads Overrides Function ProcessDialogKey(ByVal keyData As Keys) As Boolean
        Select Case keyData
            Case Keys.Escape
                ' If the Escape key is used then close the dialog and
                ' return true to avoid further processing of the key.
                Me.Close()
                Return True
        End Select
        ' Call the base class implementation.
        Return MyBase.ProcessDialogKey(keyData)
    End Function

    ' Gets a value indicating whether there is a previous page to view.
    Private ReadOnly Property HasPreviousPage() As Boolean
        Get
            Return PrintPreviewControl.StartPage > 0
        End Get
    End Property

    ' Gets a value indicating whether there is a next page to view.
    Private ReadOnly Property HasNextPage() As Boolean
        Get
            Return pagecount > (PrintPreviewControl.StartPage + 1)
        End Get
    End Property

    ' Enables and disables previous and next page buttons.
    Private Sub CheckPageStatus()
        ToolStripButtonPreviousPage.Enabled = HasPreviousPage
        ToolStripButtonNextPage.Enabled = HasNextPage
    End Sub

    Private Sub PrintDocument_BeginPrint(ByVal sender As Object, ByVal e As System.Drawing.Printing.PrintEventArgs)
        ' Initialize the page count.
        pagecount = 0
    End Sub

    Private Sub PrintDocument_EndPrint(ByVal sender As Object, ByVal e As System.Drawing.Printing.PrintEventArgs)
        ' Call routine to enable or disable previous and next page buttons.
        CheckPageStatus()
    End Sub

    Private Sub PrintDocument_PrintPage(ByVal sender As Object, ByVal e As System.Drawing.Printing.PrintPageEventArgs)
        ' Increment the page count.
        pagecount = pagecount + 1
    End Sub

    Private Sub PrintPreviewControl_StartPageChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles PrintPreviewControl.StartPageChanged
        ' Call routine to enable or disable previous and next page buttons.
        CheckPageStatus()
    End Sub

    Private Sub ToolStripButtonPrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ToolStripButtonPrint.Click
        ' Create a print dialog.
        Dim dialog As New System.Windows.Forms.PrintDialog()

        ' Set the print dialogs print document.
        dialog.Document = Document

        ' Show the print dialog and check the return status...
        If dialog.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK Then
            ' Print the document.
            Document.Print()
        End If
    End Sub

    Private Sub ToolStripButtonZoom_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ToolStripButtonZoom.Click
        If ToolStripButtonZoom.Checked Then
            ' Zoom to 100%
            PrintPreviewControl.AutoZoom = False
            PrintPreviewControl.Zoom = 1.0R
        Else
            ' Zoom is automatically determined.
            PrintPreviewControl.AutoZoom = True
        End If
    End Sub

    Private Sub ToolStripButtonPreviousPage_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ToolStripButtonPreviousPage.Click
        ' Decrement the start page if possible.
        If HasPreviousPage Then
            PrintPreviewControl.StartPage -= 1
        End If
    End Sub

    Private Sub ToolStripButtonNextPage_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ToolStripButtonNextPage.Click
        ' Increment the start page if possible.
        If HasNextPage Then
            PrintPreviewControl.StartPage += 1
        End If
    End Sub

    Private Sub ToolStripButtonClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ToolStripButtonClose.Click
        ' Close the print preview dialog.
        Me.Close()
    End Sub

End Class