Partial Class PageSetupSample

    Private Sub SetPageSetup(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet

            ' Get a reference to the worksheet's page setup.
            Dim pageSetup As SpreadsheetGear.IPageSetup = worksheet.PageSetup

            ' Set the area of the worksheet to print.
            pageSetup.PrintArea = "B1:G39"

            ' Scale printed output to 1 page tall by 1 page wide.
            pageSetup.FitToPages = True
            pageSetup.FitToPagesTall = 1
            pageSetup.FitToPagesWide = 1

            ' Horizontally center printed pages.
            pageSetup.CenterHorizontally = True

            ' Set the page orientation.
            pageSetup.Orientation = SpreadsheetGear.PageOrientation.Portrait

            ' Set page margins to 1 inch (72 points per inch)
            pageSetup.BottomMargin = 72
            pageSetup.LeftMargin = 72
            pageSetup.RightMargin = 72
            pageSetup.TopMargin = 72

            ' Set custom center header text using the specified font name and size.
            pageSetup.CenterHeader = "&""Times New Roman""&16ABC Company Sales for 2008"

            ' Set right footer to display default date and time.
            pageSetup.RightFooter = "&D &T"

            ' Show a print preview of the active worksheet.
            WorkbookView.PrintPreview()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
