Partial Class XPSDocumentSample

    Private Sub PrintToXPS(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Create a workbook print document using the active 
            ' worksheet and the option to print the entire workbook.
            Dim document As New SpreadsheetGear.Drawing.Printing.WorkbookPrintDocument( _
                WorkbookView.ActiveWorksheet, _
                SpreadsheetGear.Printing.PrintWhat.Workbook)

            Using document
                ' Get a reference to the printer settings for the document.
                Dim settings As System.Drawing.Printing.PrinterSettings = document.PrinterSettings

                ' Set the printer driver to the Microsoft XPS Document Writer print driver. 
                ' NOTE: This could be any print driver, such as the Adobe Acrobat PDF driver.
                settings.PrinterName = "Microsoft XPS Document Writer"

                ' If the printer driver is available...
                If settings.IsValid Then
                    ' Establish the filename to print to.
                    Dim filename As String = System.Environment.GetFolderPath( _
                        System.Environment.SpecialFolder.MyDocuments) & "\SpreadsheetGearXPSSample.xps"

                    ' Enable printing to a file using the specified filename.
                    settings.PrintToFile = True
                    settings.PrintFileName = filename

                    ' Print the workbook.
                    document.Print()

                    ' Launch the XPS Viewer with the XPS document.
                    System.Diagnostics.Process.Start(filename)
                Else
                    ' Show an error message.
                    System.Windows.Forms.MessageBox.Show( _
                        Me, "Printer driver is not available", "SpreadsheetGear Explorer", _
                        System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Error)
                End If
            End Using
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
