Partial Class AutoFilterSample

    Private Sub FilterSingleItem(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 0

            ' Initialize criteria1 as a single product name.
            Dim criteria1 As String = "Thyme"

            ' Filter by a single product.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Or, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterMultipleItems(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 0

            ' Initialize criteria1 as an array of product names.
            Dim criteria1 As String() = New String() {"Marjoram", "Oregano", "Rosemary"}

            ' Filter by multiple products.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Values, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterTopItems(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 2

            ' Initialize criteria1 as the number of top items.
            Dim criteria1 As Integer = 5

            ' Filter by Q1 Top Items.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Top10Items, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterTopPercent(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 3

            ' Initialize criteria1 as a percentage of top items.
            Dim criteria1 As Integer = 10

            ' Filter by Q2 Top Percent.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Top10Percent, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterBottomItems(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 4

            ' Initialize criteria1 as the number of bottom items.
            Dim criteria1 As Integer = 7

            ' Filter by Q3 Bottom Items.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Bottom10Items, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterBottomPercent(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 5

            ' Initialize criteria1 as a percentage of bottom items.
            Dim criteria1 As Integer = 10

            ' Filter by Q4 Bottom Percent.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Bottom10Percent, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterGreaterThan(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 2

            ' Initialize criteria1 using the greater than operator.
            Dim criteria1 As String = ">1850"

            ' Filter by Q1 Greater Than.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Or, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterBetween(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 3

            ' Initialize criteria1 using the greater than or equal to operator.
            Dim criteria1 As String = ">=1200"

            ' Initialize criteria2 using the less than or equal to operator.
            Dim criteria2 As String = "<=1400"

            ' Filter by Q2 Between.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.And, criteria2, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterColor(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 4

            ' Initialize criteria1 with a color.
            Dim criteria1 As SpreadsheetGear.Color = SpreadsheetGear.Colors.SeaGreen

            ' Filter by Q3 Color.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.CellColor, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub FilterIcon(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Clear any existing filters from the active worksheet.
            WorkbookView.ActiveWorksheet.AutoFilter.ShowAllData()

            ' Get a reference to cell A1.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Initialize the field index within the auto filter range.
            Dim field As Integer = 5

            ' Initialize criteria1 with the first icon in the ThreeTrafficLights1 icon set.
            Dim criteria1 As SpreadsheetGear.IIcon = _
                    WorkbookView.ActiveWorkbook.IconSets(SpreadsheetGear.IconSet.ThreeTrafficLights1)(0)

            ' Filter by Q4 Icon.
            cell.AutoFilter(field, criteria1, _
                SpreadsheetGear.AutoFilterOperator.Icon, Nothing, True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowAllData(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the AutoFilter from the worksheet.
            Dim autoFilter As SpreadsheetGear.IAutoFilter = WorkbookView.ActiveWorksheet.AutoFilter

            ' Clear filters to show all data in the auto filter range.
            autoFilter.ShowAllData()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
