Partial Class BorderSample

    Private Sub SetTopBorder(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:D8")

            ' Get a reference to the top border of the range.
            Dim border As SpreadsheetGear.IBorder = range.Borders(SpreadsheetGear.BordersIndex.EdgeTop)

            ' Set the border Linestyle, Weight, and Color.
            border.LineStyle = SpreadsheetGear.LineStyle.Continuous
            border.Weight = SpreadsheetGear.BorderWeight.Thin
            border.Color = SpreadsheetGear.Colors.Blue
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub SetLeftBorder(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:D8")

            ' Get a reference to the left border of the range.
            Dim border As SpreadsheetGear.IBorder = range.Borders(SpreadsheetGear.BordersIndex.EdgeLeft)

            ' Set the border Linestyle, Weight, and Color.
            border.LineStyle = SpreadsheetGear.LineStyle.Continuous
            border.Weight = SpreadsheetGear.BorderWeight.Medium
            border.Color = SpreadsheetGear.Colors.Green
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub SetBottomBorder(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:D8")

            ' Get a reference to the bottom border of the range.
            Dim border As SpreadsheetGear.IBorder = range.Borders(SpreadsheetGear.BordersIndex.EdgeBottom)

            ' Set the border Linestyle, Weight, and Color.
            border.LineStyle = SpreadsheetGear.LineStyle.Continuous
            border.Weight = SpreadsheetGear.BorderWeight.Thick
            border.Color = SpreadsheetGear.Colors.Yellow
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub SetRightBorder(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:D8")

            ' Get a reference to the right border of the range.
            Dim border As SpreadsheetGear.IBorder = range.Borders(SpreadsheetGear.BordersIndex.EdgeRight)

            ' Set the border Linestyle, Weight, and Color.
            border.LineStyle = SpreadsheetGear.LineStyle.Double
            border.Weight = SpreadsheetGear.BorderWeight.Thick
            border.Color = SpreadsheetGear.Colors.Red
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub SetInsideHorizontalBorder(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:D8")

            ' Get a reference to the inside horizontal border of the range.
            Dim border As SpreadsheetGear.IBorder = range.Borders(SpreadsheetGear.BordersIndex.InsideHorizontal)

            ' Set the border Linestyle, Weight, and Color.
            border.LineStyle = SpreadsheetGear.LineStyle.Continuous
            border.Weight = SpreadsheetGear.BorderWeight.Thin
            border.Color = SpreadsheetGear.Colors.DarkBlue
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub SetInsideVerticalBorder(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:D8")

            ' Get a reference to the inside vertical border of the range.
            Dim border As SpreadsheetGear.IBorder = range.Borders(SpreadsheetGear.BordersIndex.InsideVertical)

            ' Set the border Linestyle, Weight, and Color.
            border.LineStyle = SpreadsheetGear.LineStyle.Continuous
            border.Weight = SpreadsheetGear.BorderWeight.Thin
            border.Color = SpreadsheetGear.Colors.DarkGreen
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub SetAllBorders(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:D8")

            ' Get a reference to all the borders of the range.
            Dim borders As SpreadsheetGear.IBorders = range.Borders

            ' Set the border Linestyle, Weight, and Color.
            borders.LineStyle = SpreadsheetGear.LineStyle.Continuous
            borders.Weight = SpreadsheetGear.BorderWeight.Medium
            borders.Color = SpreadsheetGear.Colors.Orange
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class