Partial Class ConditionalFormatSample

    Private Sub AddColorScale(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a title to a cell.
            WorkbookView.ActiveWorksheet.Cells("A1").Formula = "Color Scale"

            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A2:A11")

            ' Load data and format as $ using multiple cell range.
            range.Formula = "=ROW() * 10 - 10"
            range.NumberFormat = "$#,##0_);($#,##0)"

            ' Get a reference to the range's conditional formats collection.
            Dim conditions As SpreadsheetGear.IFormatConditions = range.FormatConditions

            ' Delete any existing formats in the collection.
            conditions.Delete()

            ' Add color scale conditional format.
            Dim condition As SpreadsheetGear.IFormatCondition = conditions.AddColorScale(2)

            ' Get a reference to the color scale.
            Dim colorScale As SpreadsheetGear.IColorScale = condition.ColorScale

            ' Set min and max scale values.
            colorScale.ColorScaleCriteria(0).Type = SpreadsheetGear.ConditionValueTypes.Number
            colorScale.ColorScaleCriteria(0).Value = 0
            colorScale.ColorScaleCriteria(1).Type = SpreadsheetGear.ConditionValueTypes.Number
            colorScale.ColorScaleCriteria(1).Value = 100
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddDatabar(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a title to a cell.
            WorkbookView.ActiveWorksheet.Cells("B1").Formula = "Data Bar"

            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B2:B11")

            ' Load data and format as $ using multiple cell range.
            range.Formula = "=ROW() * 10 - 10"
            range.NumberFormat = "$#,##0_);($#,##0)"

            ' Get a reference to the range's conditional formats collection.
            Dim conditions As SpreadsheetGear.IFormatConditions = range.FormatConditions

            ' Delete any existing formats in the collection.
            conditions.Delete()

            ' Add data bar conditional format.
            Dim condition As SpreadsheetGear.IFormatCondition = conditions.AddDatabar()

            ' Get a reference to the data bar condition.
            Dim dataBar As SpreadsheetGear.IDatabar = condition.Databar

            ' Get a reference to the data bar border and apply formatting.
            Dim barBorder As SpreadsheetGear.IDataBarBorder = dataBar.BarBorder
            barBorder.Type = SpreadsheetGear.DataBarBorderType.Solid
            barBorder.Color.ThemeColor = SpreadsheetGear.Themes.ColorSchemeIndex.Accent1

            ' Set min and max scale values.
            dataBar.MinPoint.Modify(SpreadsheetGear.ConditionValueTypes.Number, 0)
            dataBar.MaxPoint.Modify(SpreadsheetGear.ConditionValueTypes.Number, 100)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddIconSet(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a title to a cell.
            WorkbookView.ActiveWorksheet.Cells("C1").Formula = "Icon Set"

            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("C2:C11")

            ' Load random data and format as $ using multiple cell range.
            range.Formula = "=RAND() * 10000"
            range.NumberFormat = "$#,##0_);($#,##0)"

            ' Get a reference to the range's conditional formats collection.
            Dim conditions As SpreadsheetGear.IFormatConditions = range.FormatConditions

            ' Delete any existing formats in the collection.
            conditions.Delete()

            ' Add icon set conditional format.
            Dim condition As SpreadsheetGear.IFormatCondition = conditions.AddIconSetCondition()

            ' Get a reference to the icon set condition.
            Dim iconSet As SpreadsheetGear.IIconSetCondition = condition.IconSetCondition

            ' Set the icon set type.
            iconSet.IconSet = WorkbookView.ActiveWorkbook.IconSets(SpreadsheetGear.IconSet.FiveQuarters)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddTop10(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a title to a cell.
            WorkbookView.ActiveWorksheet.Cells("D1").Formula = "Top 10"

            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("D2:D11")

            ' Load random data and format as $ using multiple cell range.
            range.Formula = "=RAND() * 10000"
            range.NumberFormat = "$#,##0_);($#,##0)"

            ' Get a reference to the range's conditional formats collection.
            Dim conditions As SpreadsheetGear.IFormatConditions = range.FormatConditions

            ' Delete any existing formats in the collection.
            conditions.Delete()

            ' Add Top 10 conditional format.
            Dim condition As SpreadsheetGear.IFormatCondition = conditions.AddTop10()

            ' Get a reference to the Top 10 condition.
            Dim top10 As SpreadsheetGear.ITop10 = condition.Top10

            ' Set the rank to only format the top 2 values.
            top10.Rank = 2

            ' Set font and interior formatting options.
            condition.Font.Bold = True
            condition.Font.Italic = True
            condition.Font.Color = SpreadsheetGear.Colors.White
            condition.Interior.Color = SpreadsheetGear.Colors.Green
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddAboveAverage(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a title to a cell.
            WorkbookView.ActiveWorksheet.Cells("E1").Formula = "Above Average"

            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("E2:E11")

            ' Load random data and format as $ using multiple cell range.
            range.Formula = "=RAND() * 10000"
            range.NumberFormat = "$#,##0_);($#,##0)"

            ' Get a reference to the range's conditional formats collection.
            Dim conditions As SpreadsheetGear.IFormatConditions = range.FormatConditions

            ' Delete any existing formats in the collection.
            conditions.Delete()

            ' Add above average conditional format.
            Dim condition As SpreadsheetGear.IFormatCondition = conditions.AddAboveAverage()

            ' Get a reference to the above average condition.
            Dim aboveAverage As SpreadsheetGear.IAboveAverage = condition.AboveAverage

            ' Display formatting for values equal or above average.
            aboveAverage.AboveBelow = SpreadsheetGear.AboveBelow.EqualAboveAverage

            ' Set font And interior formatting options.
            condition.Font.Bold = True
            condition.Font.Italic = True
            condition.Font.Color = SpreadsheetGear.Colors.White
            condition.Interior.Color = SpreadsheetGear.Colors.DarkViolet
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddUniqueValues(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a title to a cell.
            WorkbookView.ActiveWorksheet.Cells("F1").Formula = "Unique Values"

            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("F2:F11")

            ' Load random data and format as $ using multiple cell range.
            range.Formula = "=RAND() * 10000"
            range.NumberFormat = "$#,##0_);($#,##0)"

            ' Set some duplicate values.
            range(2, 0).Value = 100
            range(5, 0).Value = 100

            ' Get a reference to the range's conditional formats collection.
            Dim conditions As SpreadsheetGear.IFormatConditions = range.FormatConditions

            ' Delete any existing formats in the collection.
            conditions.Delete()

            ' Add unique values conditional format.
            Dim condition As SpreadsheetGear.IFormatCondition = conditions.AddUniqueValues()

            ' Get a reference to the unique values condition.
            Dim uniqueValues As SpreadsheetGear.IUniqueValues = condition.UniqueValues

            ' Display formatting for values that are duplicates.
            uniqueValues.DupeUnique = SpreadsheetGear.DupeUnique.Duplicate

            ' Set font and interior formatting options.
            condition.Font.Bold = True
            condition.Font.Italic = True
            condition.Interior.Color = SpreadsheetGear.Colors.LightSalmon
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddCellValue(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Add a title to a cell.
            WorkbookView.ActiveWorksheet.Cells("G1").Formula = "Cell Value"

            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("G2:G11")

            ' Load random data and format as $ using multiple cell range.
            range.Formula = "=RAND() * 10000"
            range.NumberFormat = "$#,##0_);($#,##0)"

            ' Get a reference to the range's conditional formats collection.
            Dim conditions As SpreadsheetGear.IFormatConditions = range.FormatConditions

            ' Delete any existing formats in the collection.
            conditions.Delete()

            ' Add a conditional format for values less than or equal to 7000.
            Dim condition As SpreadsheetGear.IFormatCondition = conditions.Add( _
                SpreadsheetGear.FormatConditionType.CellValue, _
                SpreadsheetGear.FormatConditionOperator.LessEqual, "7000", Nothing)

            ' Set font and interior formatting options.
            condition.Font.Bold = False
            condition.Font.Color = SpreadsheetGear.Colors.White
            condition.Interior.Color = SpreadsheetGear.Colors.DarkSlateBlue

            ' Add a conditional format for values greater than 7000.
            condition = conditions.Add( _
                SpreadsheetGear.FormatConditionType.CellValue, _
                SpreadsheetGear.FormatConditionOperator.Greater, "7000", Nothing)

            ' Set font and interior formatting options.
            condition.Font.Bold = True
            condition.Font.Italic = True
            condition.Font.Color = SpreadsheetGear.Colors.White
            condition.Interior.Color = SpreadsheetGear.Colors.Maroon
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub Recalc(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Recalculate the random values.
            WorkbookView.ActiveWorkbookSet.Calculate()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
