Partial Class FindReplaceSample

    Private Sub FindNext(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the worksheet's cells.
            Dim cells As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells

            ' Get a reference to the active cell.
            Dim activeCell As SpreadsheetGear.IRange = WorkbookView.ActiveCell

            ' Find the next cell after the active cell which contains the word "Text".
            ' Require only a partial match by specifying LookAt.Part.
            Dim findCell As SpreadsheetGear.IRange = cells.Find("Text", activeCell, _
                SpreadsheetGear.FindLookIn.Formulas, SpreadsheetGear.LookAt.Part, _
                SpreadsheetGear.SearchOrder.ByRows, SpreadsheetGear.SearchDirection.Next, False)

            ' If a cell was found, select it, otherwise show an error.
            If Not (findCell Is Nothing) Then
                findCell.Select()
            Else
                System.Windows.Forms.MessageBox.Show( _
                    "No match was found.", "SpreadsheetGear")
            End If
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub Replace(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the worksheet's cells.
            Dim cells As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells

            ' Replace all occurences of the word "Text" with "New Text".
            ' Require an exact match by specifying LookAt.Whole.
            Dim replaceCount As Integer = cells.Replace("Text", "New Text", _
                SpreadsheetGear.LookAt.Whole, SpreadsheetGear.SearchOrder.ByRows, False)

            ' Show an error if nothing was replaced.
            If replaceCount = 0 Then
                System.Windows.Forms.MessageBox.Show( _
                    "No cells were replaced.", "SpreadsheetGear")
            End If
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
