Partial Class HyperlinkSample

    Private Sub AddHyperlink(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet

            ' Get a reference to the worksheet's hyperlink collection.
            Dim hyperlinks As SpreadsheetGear.IHyperlinks = worksheet.Hyperlinks

            ' Delete all hyperlinks in the collection.
            hyperlinks.Delete()

            ' Add a hyperlink referencing a range.
            hyperlinks.Add(worksheet.Cells("A2"), _
                Nothing, "C:C", Nothing, "Column C")

            ' Add a hyperlink referencing a range on another worksheet.
            hyperlinks.Add(worksheet.Cells("A3"), _
                Nothing, "Sheet2!A1:D4", Nothing, "Range on Sheet2")

            ' Add a hyperlink referencing a web page.
            hyperlinks.Add(worksheet.Cells("A4"), _
                "http://www.spreadsheetgear.com", Nothing, Nothing, "www.spreadsheetgear.com")

            ' Add a hyperlink referencing an email address.
            hyperlinks.Add(worksheet.Cells("A5"), _
                "mailto:sales@spreadsheetgear.com", Nothing, Nothing, "sales@spreadsheetgear.com")

            ' Add a hyperlink referencing an email address with a subject.
            hyperlinks.Add(worksheet.Cells("A6"), _
                "mailto:support@spreadsheetgear.com?subject=Support Request", Nothing, Nothing, "support@spreadsheetgear.com")

            ' Add some text and set the column width.
            worksheet.Cells("A1").Formula = "Hyperlink Examples"
            worksheet.Cells("A1").ColumnWidth = 30
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
