Partial Class LockingSample

    Private Sub SetLocked(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet

            ' Is the worksheet already protected?
            If worksheet.ProtectContents <> True Then
                ' Add a couple of labels and autofit the column.
                Dim cells As SpreadsheetGear.IRange = worksheet.Cells
                cells("A1").Value = "Row 1 is not locked - you can edit this cell."
                cells("A2").Value = "All other rows are locked - you cannot edit this cell."
                cells("A1:A2").Columns.AutoFit()

                ' Get a reference to row 1.
                Dim row1 As SpreadsheetGear.IRange = cells("1:1")

                ' Unlock the range of cells. (NOTE: Cells are locked by default)
                row1.Locked = False

                ' Enable protection for the worksheet.
                worksheet.ProtectContents = True
            End If

            ' Give the keyboard focus to the WorkbookView.
            WorkbookView.Focus()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
