Partial Class SortSample

    Private Sub Sort(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a range of cells.
            Dim range As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1:B8")

            ' Load products in no particular order.
            range(0, 0).Formula = "Oregano"
            range(1, 0).Formula = "Marjoram"
            range(2, 0).Formula = "Basil"
            range(3, 0).Formula = "Rosemary"
            range(4, 0).Formula = "Thyme"
            range(5, 0).Formula = "Black Pepper"
            range(6, 0).Formula = "Garlic Powder"
            range(7, 0).Formula = "Chili Powder"

            ' Load random data and format as $ using multiple cell range.
            Dim body As SpreadsheetGear.IRange = range(0, 1, 7, 1)
            body.Formula = "=ROUND(RAND() * 5000, -3)"
            body.NumberFormat = "$#,##0_);($#,##0)"

            ' Get rid of formulas...
            body.Value = body.Value

            ' Set up the first sort key with a key index of one representing the second
            ' column (random $ amounts) in the range, descending sort order, and the
            ' normal data option.
            Dim sortKey1 As New SpreadsheetGear.SortKey( _
                1, SpreadsheetGear.SortOrder.Descending, SpreadsheetGear.SortDataOption.Normal)

            ' Set up the second sort key with a key index of zero representing the first
            ' column (products) in the range, ascending sort order, and the normal data option.
            '
            ' This sort key will be used when the values in the first sort key are equal.
            Dim sortKey2 As New SpreadsheetGear.SortKey( _
                0, SpreadsheetGear.SortOrder.Ascending, SpreadsheetGear.SortDataOption.Normal)

            ' Sort the range by rows, ignoring case, passing the sort key.
            ' NOTE: Any number of sort keys may be passed to the Sort method.
            range.Sort(SpreadsheetGear.SortOrientation.Rows, False, sortKey1, sortKey2)

            ' AutoFit the range.
            range.Columns.AutoFit()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
