Partial Class ValidationSample

    Private Sub AddValidationWholeNumber(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a cell.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("A1")

            ' Get a reference to the cell's validation.
            Dim validation As SpreadsheetGear.IValidation = cell.Validation

            ' Delete any existing validation.
            validation.Delete()

            ' Add data validation which will force the user to
            ' enter a whole number greater than zero.
            validation.Add( _
                SpreadsheetGear.ValidationType.WholeNumber, _
                 SpreadsheetGear.ValidationAlertStyle.Stop, _
                 SpreadsheetGear.ValidationOperator.Greater, "0", Nothing)

            ' Set the error message to display if validation fails.
            validation.ErrorMessage = "You must enter a whole number greater than zero!"

            ' Set the input message to display when the cell is active.
            validation.InputMessage = "Enter a whole number greater than zero."

            ' Select the cell and give focus to the WorkbookView so
            ' that the validation input message tooltip will display.
            cell.Select()
            WorkbookView.Focus()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddValidationListValues(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a cell.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B1")

            ' Add data validation which will provide a drop-down 
            ' list of values to choose from.  Users will be warned 
            ' if they try to enter a value that is not in the list.
            cell.Validation.Add( _
                SpreadsheetGear.ValidationType.List, _
                 SpreadsheetGear.ValidationAlertStyle.Warning, _
                 SpreadsheetGear.ValidationOperator.Default, "Red,Green,Blue", Nothing)

            ' Select the cell.
            cell.Select()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub AddValidationListLinked(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Load sample data.
            Dim cells As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("C3:C5")
            cells(0, 0).Formula = "Cold"
            cells(1, 0).Formula = "Warm"
            cells(2, 0).Formula = "Hot"

            ' Get a reference to a cell.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("C1")

            ' Add data validation which will provide a drop-down 
            ' list of values to choose from.  This list is generated
            ' from a list of cell values.  Users will be informed 
            ' if they try to enter a value that is not in the list.
            cell.Validation.Add( _
                SpreadsheetGear.ValidationType.List, _
                 SpreadsheetGear.ValidationAlertStyle.Information, _
                 SpreadsheetGear.ValidationOperator.Default, "=C3:C5", Nothing)

            ' Select the cell.
            cell.Select()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class