Partial Class DataSetToWorkbookSample

    Private Sub RunReport(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Create a DataSet from an XML file.
            Dim dataset As New System.Data.DataSet()
            dataset.ReadXml("nfl.xml")

            ' Get the active workbook set to hold the 
            ' template workbook and the report workbook.
            Dim workbookSet As SpreadsheetGear.IWorkbookSet = WorkbookView.ActiveWorkbookSet

            ' Close any open workbooks and create the report workbook.
            workbookSet.Workbooks.Close()
            Dim reportWorkbook As SpreadsheetGear.IWorkbook = workbookSet.Workbooks.Add()

            ' Open the template workbook which contains formats, borders and formulas.
            Dim templateWorkbook As SpreadsheetGear.IWorkbook = workbookSet.Workbooks.Open("nfltemplate.xls")

            ' Get the template range from a defined name in the template workbook.
            Dim templateRange As SpreadsheetGear.IRange = templateWorkbook.Names("NFLDivisionFormat").RefersToRange

            ' Get the number of rows and columns in the template range.
            Dim templateRangeRowCount As Integer = templateRange.RowCount
            Dim templateRangeColCount As Integer = templateRange.ColumnCount

            ' Get the worksheet to hold the new spreadsheet report.
            Dim reportWorksheet As SpreadsheetGear.IWorksheet = reportWorkbook.Worksheets(0)
            reportWorksheet.WindowInfo.DisplayGridlines = False
            reportWorksheet.Name = dataset.DataSetName

            ' Start at cell B2.
            Dim row As Integer = 1
            Dim col As Integer = 1

            ' Insert each DataTable from the DataSet...
            Dim datatable As System.Data.DataTable
            For Each datatable In dataset.Tables
                ' Get the destination range in the report worksheet.
                Dim dstRange As SpreadsheetGear.IRange = reportWorksheet.Cells(row, col, row + templateRangeRowCount - 1, col + templateRangeColCount - 1)

                ' Copy the template range formats and formulas to the report worksheet.
                templateRange.Copy(dstRange, SpreadsheetGear.PasteType.All, SpreadsheetGear.PasteOperation.None, False, False)

                If row = 1 Then
                    ' Copy the template range column widths to the report worksheet once.
                    templateRange.Copy(dstRange, SpreadsheetGear.PasteType.ColumnWidths, SpreadsheetGear.PasteOperation.None, False, False)
                End If

                ' Use the TableName for the title of the range - this is a merged
                ' cell centered across the top of the destination range.
                reportWorksheet.Cells(row, col).Formula = datatable.TableName

                ' Add a defined name for the new destination range. This defined
                ' name will be adjusted by IRange.CopyFromDataTable, allowing us
                ' to skip over the newly inserted range and any summary rows
                ' added by the template.
                Dim dstRangeName As SpreadsheetGear.IName = reportWorkbook.Names.Add(datatable.TableName.Replace(" ", ""), "=" + dstRange.Address)

                ' Insert the DataTable into the worksheet.  This will adjust the defined name,
                ' as well as the formats, cell borders and formulas which were copied from
                ' the template workbook.
                reportWorksheet.Cells(row + 1, col, row + 3, col).CopyFromDataTable(datatable, SpreadsheetGear.Data.SetDataFlags.InsertCells)

                ' Update the row counter to the end of the inserted table.
                Dim range As SpreadsheetGear.IRange = dstRangeName.RefersToRange
                row = range.Row + range.RowCount + 1
            Next datatable
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class