Partial Class FormulasFormatsSample

    Private Sub RunReport(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a workbook reference.
            Dim workbook As SpreadsheetGear.IWorkbook = WorkbookView.ActiveWorkbook

            ' Get a worksheet and change the name.
            Dim worksheet As SpreadsheetGear.IWorksheet = workbook.Worksheets(0)
            worksheet.Name = "2005 Sales"

            ' Get the worksheet cells reference.
            Dim cells As SpreadsheetGear.IRange = worksheet.Cells

            ' Add column headers.
            cells("B1").Formula = "Jan"
            cells("C1").Formula = "Feb"
            cells("D1").Formula = "Mar"

            ' Add row headers.
            cells("A2").Formula = "West"
            cells("A3").Formula = "Central"
            cells("A4").Formula = "East"

            ' Add random data.
            cells("B2:D4").Formula = "=RAND()*10000"

            ' Center the column headers.
            cells("B1:D1").HorizontalAlignment = SpreadsheetGear.HAlign.Center

            ' Bold the row and column headers.
            cells("B1:D1,A2:A4").Font.Bold = True

            ' Add defined names.
            Dim names As SpreadsheetGear.INames = workbook.Names
            names.Add("Jan", "='2005 Sales'!$B$2:$B$4")
            names.Add("Feb", "='2005 Sales'!$C$2:$C$4")
            names.Add("Mar", "='2005 Sales'!$D$2:$D$4")
            names.Add("Sales", "='2005 Sales'!$B$2:$D$4")

            ' Format sales data as currency.
            cells("Sales").NumberFormat = "$#,##0"

            ' Add a hyperlink referencing a web page.
            worksheet.Hyperlinks.Add(cells("A6"), _
                "http://www.spreadsheetgear.com", Nothing, Nothing, "www.spreadsheetgear.com")

            ' Merge some cells.
            cells("A6:C6").Merge()
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class