Partial Class WorkbookConsolidationSample

    Private Sub RunReport(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            Dim workbook As SpreadsheetGear.IWorkbook
            If RadioButtonAll.Checked Then
                ' Create a new workbook and name the first sheet.
                workbook = SpreadsheetGear.Factory.GetWorkbook( _
                    System.Globalization.CultureInfo.CurrentCulture)
                Dim worksheet As SpreadsheetGear.IWorksheet = workbook.Worksheets(0)
                worksheet.Name = "Total Sales"

                ' Copy all region templates to the new worksheet.
                CopyRegion(worksheet, "North", SpreadsheetGear.PasteOperation.None)
                CopyRegion(worksheet, "South", SpreadsheetGear.PasteOperation.Add)
                CopyRegion(worksheet, "East", SpreadsheetGear.PasteOperation.Add)
                CopyRegion(worksheet, "West", SpreadsheetGear.PasteOperation.Add)

                ' Auto size all worksheet columns which contain data.
                worksheet.UsedRange.Columns.AutoFit()
            Else
                ' Get the region that is selected.
                Dim region As String
                If RadioButtonNorth.Checked Then
                    region = "North"
                ElseIf RadioButtonSouth.Checked Then
                    region = "South"
                Else If RadioButtonEast.Checked Then
                    region = "East"
                Else
                    region = "West"
                End If

                ' Get a workbook for the selected region.
                workbook = GetWorkbookForRegion(region)
            End If

            ' Set the new workbook as the active workbook.
            WorkbookView.ActiveWorkbook = workbook
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub CopyRegion(ByVal dstWorksheet As SpreadsheetGear.IWorksheet, ByVal region As String, ByVal pasteOperation As SpreadsheetGear.PasteOperation)
        ' Open the specified region workbook and get the source range.
        Dim srcWorkbook As SpreadsheetGear.IWorkbook = GetWorkbookForRegion(region)
        Dim srcRange As SpreadsheetGear.IRange = srcWorkbook.Names("YearSales").RefersToRange

        ' Set up our destination range to match the size of the source range.
        Dim address As String = srcRange.Address
        Dim dstRange As SpreadsheetGear.IRange = dstWorksheet.Cells(address)

        ' Copy the source range values and formats to the destination range.
        ' We have to call copy twice here since there is currently no PasteType
        ' which does values and all formats together. This is a limitaion in 
        ' the Excel API, but probably should be added to the SpreadsheetGear API.
        srcRange.Copy(dstRange, SpreadsheetGear.PasteType.Values, pasteOperation, True, False)

        srcRange.Copy(dstRange, SpreadsheetGear.PasteType.Formats, pasteOperation, True, False)

        ' Set the destination worksheet row heights to match the source range.
        dstWorksheet.Cells.RowHeight = srcRange.RowHeight
    End Sub

    Private Function GetWorkbookForRegion(ByVal region As String) As SpreadsheetGear.IWorkbook
        ' Get the filename from the region name.
        Dim filename As String
        Select Case region
            Case "North"
                filename = "spicenorth.xls"
            Case "South"
                filename = "spicesouth.xls"
            Case "East"
                filename = "spiceeast.xls"
            Case "West"
                filename = "spicewest.xls"
            Case Else
                filename = "spicewest.xls"
        End Select

        ' Return a workbook from the filename.
        Return SpreadsheetGear.Factory.GetWorkbook(filename, System.Globalization.CultureInfo.CurrentCulture)
    End Function

End Class