Partial Class AutoShapesSample

    Private Sub AddAutoShapes(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet and window info.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo

            ' Get a reference to the worksheet's shapes collection.
            Dim shapes As SpreadsheetGear.Shapes.IShapes = worksheet.Shapes

            ' Delete any existing shapes in the shapes collection.
            While shapes.Count > 0
                shapes(0).Delete()
            End While

            ' Add a variety of auto shapes.
            Dim iRow As Integer
            For iRow = 0 To 12 - 3 Step 3
                Dim iCol As Integer
                For iCol = 0 To 6
                    ' Calculate the left, top, width and height of the shape by 
                    ' converting row and column coordinates to points.  Use fractional 
                    ' values to get coordinates in between row and column boundaries.
                    Dim left As Double = windowInfo.ColumnToPoints((iCol + 0.1))
                    Dim top As Double = windowInfo.RowToPoints((iRow + 0.2))
                    Dim right As Double = windowInfo.ColumnToPoints((iCol + 0.9))
                    Dim bottom As Double = windowInfo.RowToPoints((iRow + 2.8))
                    Dim width As Double = right - left
                    Dim height As Double = bottom - top

                    ' Get the next sample auto shape type.
                    Dim autoShapeType As SpreadsheetGear.Shapes.AutoShapeType = GetAutoShapeType(shapes.Count)

                    ' Add the shape using the calculated bounds.
                    Dim shape As SpreadsheetGear.Shapes.IShape = _
                        shapes.AddShape(autoShapeType, left, top, width, height)

                    ' Set fill color with increased transparency for each shape.
                    Dim fillFormat As SpreadsheetGear.Shapes.IFillFormat = shape.Fill
                    fillFormat.ForeColor.RGB = SpreadsheetGear.Colors.DarkSlateBlue
                    fillFormat.Transparency = (shapes.Count - 1.0) * 0.03

                    ' Set line color.
                    Dim lineFormat As SpreadsheetGear.Shapes.ILineFormat = shape.Line
                    lineFormat.ForeColor.RGB = SpreadsheetGear.Colors.Maroon

                    ' Set line to dash line style.
                    lineFormat.DashStyle = SpreadsheetGear.Shapes.LineDashStyle.Dash
                Next iCol
            Next iRow
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    '
    ' SpreadsheetGear for .NET supports all of Excel's auto shape types
    ' in the SpreadsheetGear.Shapes.IShapes API (more than 100 types).
    '
    ' The WorkbookView control currently supports and renders a subset of
    ' these auto shape types including the ones listed below and used in
    ' this sample.  See the Shape Explorer's AutoShape category for a
    ' complete list of auto shapes supported in the WorkbookView control.
    '
    Private Function GetAutoShapeType(ByVal index As Integer) As SpreadsheetGear.Shapes.AutoShapeType
        Select Case index
            Case 0
                Return SpreadsheetGear.Shapes.AutoShapeType.Rectangle
            Case 1
                Return SpreadsheetGear.Shapes.AutoShapeType.Parallelogram
            Case 2
                Return SpreadsheetGear.Shapes.AutoShapeType.Trapezoid
            Case 3
                Return SpreadsheetGear.Shapes.AutoShapeType.Diamond
            Case 4
                Return SpreadsheetGear.Shapes.AutoShapeType.Oval
            Case 5
                Return SpreadsheetGear.Shapes.AutoShapeType.Cross
            Case 6
                Return SpreadsheetGear.Shapes.AutoShapeType.IsoscelesTriangle
            Case 7
                Return SpreadsheetGear.Shapes.AutoShapeType.RightTriangle
            Case 8
                Return SpreadsheetGear.Shapes.AutoShapeType.Octagon
            Case 9
                Return SpreadsheetGear.Shapes.AutoShapeType.Hexagon
            Case 10
                Return SpreadsheetGear.Shapes.AutoShapeType.RegularPentagon
            Case 11
                Return SpreadsheetGear.Shapes.AutoShapeType.FlowchartManualInput
            Case 12
                Return SpreadsheetGear.Shapes.AutoShapeType.FlowchartOffpageConnector
            Case 13
                Return SpreadsheetGear.Shapes.AutoShapeType.FlowchartMerge
            Case 14
                Return SpreadsheetGear.Shapes.AutoShapeType.FlowchartCollate
            Case 15
                Return SpreadsheetGear.Shapes.AutoShapeType.FlowchartSort
            Case 16
                Return SpreadsheetGear.Shapes.AutoShapeType.RightArrow
            Case 17
                Return SpreadsheetGear.Shapes.AutoShapeType.LeftArrow
            Case 18
                Return SpreadsheetGear.Shapes.AutoShapeType.UpArrow
            Case 19
                Return SpreadsheetGear.Shapes.AutoShapeType.DownArrow
            Case 20
                Return SpreadsheetGear.Shapes.AutoShapeType.LeftRightArrow
            Case 21
                Return SpreadsheetGear.Shapes.AutoShapeType.UpDownArrow
            Case 22
                Return SpreadsheetGear.Shapes.AutoShapeType.RightArrowCallout
            Case 23
                Return SpreadsheetGear.Shapes.AutoShapeType.LeftArrowCallout
            Case 24
                Return SpreadsheetGear.Shapes.AutoShapeType.UpArrowCallout
            Case 25
                Return SpreadsheetGear.Shapes.AutoShapeType.DownArrowCallout
            Case 26
                Return SpreadsheetGear.Shapes.AutoShapeType.LeftRightArrowCallout
            Case 27
                Return SpreadsheetGear.Shapes.AutoShapeType.UpDownArrowCallout
        End Select
        Return SpreadsheetGear.Shapes.AutoShapeType.Rectangle
    End Function

End Class
