Partial Class PictureSample

    Private Sub AddPicture(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet and worksheet window info.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo

            ' Set up the image file name.
            Dim filename As String = "ssgear.gif"

            ' Get the width and height of the picture in pixels and convert to
            ' points for use in the call to AddPicture.  This step is only
            ' necessary if the actual picture size is to be used and that size
            ' is unknown.  Another option is to calculate the width and height 
            ' in row and column coordinates in the same manner as the left 
            ' and top are calculated in the code below.
            Dim width As Double
            Dim height As Double
            Dim image As System.Drawing.Image = System.Drawing.Image.FromFile(filename)
            Using (image)
                width = image.Width * 72.0 / image.HorizontalResolution
                height = image.Height * 72.0 / image.VerticalResolution
            End Using

            ' Calculate the left and top coordinates of the picture by converting 
            ' row and column coordinates to points.  Use fractional values to 
            ' get coordinates anywhere in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(0.25)
            Dim top As Double = windowInfo.RowToPoints(1.5)

            ' Add the picture from file using the calculated bounds.
            Dim shape As SpreadsheetGear.Shapes.IShape = _
                worksheet.Shapes.AddPicture(filename, left, top, width, height)

            ' Remove the border around the picture shape.
            shape.Line.Visible = False

            ' Select the picture.
            shape.Select(True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
