Partial Class TextBoxSample

    Private Sub AddTextBox(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet and worksheet window info.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = worksheet.WindowInfo

            ' Calculate the left, top, width and height of the textbox by 
            ' converting row and column coordinates to points.  Use fractional 
            ' values to get coordinates in between row and column boundaries.
            Dim left As Double = windowInfo.ColumnToPoints(0.5)
            Dim top As Double = windowInfo.RowToPoints(1.5)
            Dim right As Double = windowInfo.ColumnToPoints(5.5)
            Dim bottom As Double = windowInfo.RowToPoints(10.5)
            Dim width As Double = right - left
            Dim height As Double = bottom - top

            ' Add the textbox using the calculated bounds.
            Dim shape As SpreadsheetGear.Shapes.IShape = _
                worksheet.Shapes.AddTextBox(left, top, width, height)

            ' Get a reference to the shape's textframe and characters.
            Dim textFrame As SpreadsheetGear.Shapes.ITextFrame = shape.TextFrame
            Dim characters As SpreadsheetGear.ICharacters = textFrame.Characters

            ' Set the text to display in the textbox.
            characters.Text = "SpreadsheetGear for .NET..." + _
                ControlChars.Cr + ControlChars.Lf + ControlChars.Cr + ControlChars.Lf + _
                "Now includes API and GUI support for cell comments, data validation, " + _
                "pictures, text boxes, check boxes, dropdowns, " + _
                "list boxes, spinners, scrollbars, buttons, lines, " + _
                "many autoshapes and more..."

            ' Set various font options.
            Dim font As SpreadsheetGear.IFont = characters.Font
            font.Italic = True
            font.Name = "Times New Roman"
            font.Size = 12

            ' Select the textbox.
            shape.Select(True)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
