Partial Class DisplayReferenceSample

    Private Sub SetDisplayReference(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            If RadioButtonWorkbook.Checked Then
                ' Change the display reference to an entire workbook.
                WorkbookView.DisplayReference = "Book2"
                WorkbookView.DisplayReferenceName = Nothing
            ElseIf RadioButtonWorksheet.Checked Then
                ' Change the display reference to an entire worksheet.
                '
                ' Note that this sample uses single quotes around the reference 
                ' because the sheet name has a space in it.
                WorkbookView.DisplayReference = "'[Book1]My Worksheet'!A:XFD"

                ' Change the text displayed in the WorkbookView tabs.
                WorkbookView.DisplayReferenceName = """My Worksheet Tab"""
             ElseIf RadioButtonRange.Checked Then
                ' Change the display reference to a single range.
                WorkbookView.DisplayReference = "[Book3]Sheet2!A1:E8"

                ' Change the text displayed in the WorkbookView tabs.
                WorkbookView.DisplayReferenceName = """My Range"""

                ' Change the extra color diplayed beyond the last row and column.
                WorkbookView.ExtraColor = System.Drawing.Color.SlateBlue
            ElseIf RadioButtonDefinedName.Checked Then
                ' Change the display reference to a defined name.
                WorkbookView.DisplayReference = "Book2!MyName"

                ' Change the text displayed in the WorkbookView tabs.
                WorkbookView.DisplayReferenceName = """My Defined Name"""

                ' Change the extra color diplayed beyond the last row and column.
                WorkbookView.ExtraColor = System.Drawing.Color.SlateBlue
            ElseIf RadioButtonMultipleRanges.Checked Then
                ' Change the display reference to multiple ranges.
                WorkbookView.DisplayReference = "[Book1]Sheet1!A1:D5,[Book1]Sheet1!4:6,[Book1]Sheet1!D:F"

                ' Change the text displayed in the WorkbookView tabs.
                WorkbookView.DisplayReferenceName = """My Range1"",""My Range2"",""My Range3"""

                ' Change the extra color diplayed beyond the last row and column.
                WorkbookView.ExtraColor = System.Drawing.Color.SlateBlue
            ElseIf RadioButtonUsedRanges.Checked Then
                ' Get a reference to a workbook.
                Dim workbook As SpreadsheetGear.IWorkbook = _
                    WorkbookView.ActiveWorkbookSet.Workbooks("Book4")

                ' Get a reference to the workbook's worksheet collection.
                Dim worksheets As SpreadsheetGear.IWorksheets = workbook.Worksheets

                ' Get the name of the workbook.
                Dim bookName As String = workbook.Name

                ' Get the last sheet index.
                Dim lastSheetIndex As Integer = worksheets.Count - 1

                ' Initialize the display reference variable.
                Dim displayReference As String = ""

                ' Dynamically build a display reference which will include
                ' the used portion of all worksheets in the workbook.
                For sheetIndex As Integer = 0 To lastSheetIndex
                    ' Get a reference to the worksheet at the specified index.
                    Dim worksheet As SpreadsheetGear.IWorksheet = worksheets(sheetIndex)

                    ' Get a reference to the used area of the worksheet.
                    Dim usedRange As SpreadsheetGear.IRange = worksheet.UsedRange

                    ' Get the name of the worksheet.
                    Dim sheetName As String = worksheet.Name

                    ' Get the range address of the used range.
                    Dim rangeName As String = usedRange.Address

                    ' Append the information to the display reference.
                    displayReference = displayReference + "'[" + bookName + "]" + sheetName + "'!" + rangeName

                    ' Add a separator if there are more ranges to add.
                    If sheetIndex < lastSheetIndex Then
                        displayReference = displayReference + ","
                    End If
                Next

                ' Set the display reference.
                WorkbookView.DisplayReference = displayReference

                ' Clear display names so that the actual worksheet names are used.
                WorkbookView.DisplayReferenceName = Nothing

                ' Change the extra color diplayed beyond the last row and column.
                WorkbookView.ExtraColor = System.Drawing.Color.SlateBlue
            End If
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
