Partial Class WorksheetWindowInfoSample

    Private Sub FreezePanes(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet window info.
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = WorkbookView.ActiveWorksheetWindowInfo

            ' Display the first row at the top.
            windowInfo.ScrollRow = 0

            ' Display the first column at the left.
            windowInfo.ScrollColumn = 0

            ' Split two rows.
            windowInfo.SplitRows = 2

            ' Split one column.
            windowInfo.SplitColumns = 1

            ' Freeze the top and left panes.
            windowInfo.FreezePanes = True
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub DisplayGridlines(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet window info.
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = WorkbookView.ActiveWorksheetWindowInfo

            ' Display gridlines.
            windowInfo.DisplayGridlines = True

            ' Set the color of the gridlines.
            windowInfo.GridlineColor = SpreadsheetGear.Colors.SlateBlue
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ToggleHeadings(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the active worksheet window info.
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = WorkbookView.ActiveWorksheetWindowInfo

            ' Toggle display of row and column headings.
            windowInfo.DisplayHeadings = Not windowInfo.DisplayHeadings
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub Zoom(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to a cell and it's font.
            Dim cell As SpreadsheetGear.IRange = WorkbookView.ActiveWorksheet.Cells("B3")
            Dim font As SpreadsheetGear.IFont = cell.Font

            ' Add text and set font options.
            cell.Value = "SpreadsheetGear for .NET"
            font.Name = "Times New Roman"
            font.Bold = True
            font.Color = SpreadsheetGear.Colors.SlateBlue

            ' Get a reference to the active worksheet window info.
            Dim windowInfo As SpreadsheetGear.IWorksheetWindowInfo = WorkbookView.ActiveWorksheetWindowInfo

            While windowInfo.Zoom < 400
                ' Set the zoom factor.
                windowInfo.Zoom = windowInfo.Zoom + 10

                ' NOTE: This call to Refresh is not required and is only
                '       here for sample purposes to update the control.
                WorkbookView.Refresh()
            End While

            While windowInfo.Zoom > 100
                ' Set the zoom factor.
                windowInfo.Zoom = windowInfo.Zoom - 10

                ' NOTE: This call to Refresh is not required and is only
                '       here for sample purposes to update the control.
                WorkbookView.Refresh()
            End While
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

End Class
