Partial Class FormSample

    Private Sub ShowWorkbookDesigner(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get the active workbook set.
            Dim workbookSet As SpreadsheetGear.IWorkbookSet = WorkbookView.ActiveWorkbookSet

            ' Create the Workbook Designer for the active workbook set.
            Dim designer As New SpreadsheetGear.Windows.Forms.WorkbookDesigner(workbookSet)

            ' Set up some event handlers.
            AddHandler designer.Shown, AddressOf WorkbookDesigner_Shown
            AddHandler designer.FormClosed, AddressOf WorkbookDesigner_FormClosed

            ' Display the Workbook Designer to the user.
            designer.Show(WorkbookView)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowWorkbookExplorer(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get the active workbook set.
            Dim workbookSet As SpreadsheetGear.IWorkbookSet = WorkbookView.ActiveWorkbookSet

            ' Create the Workbook Explorer for the active workbook set.
            Dim explorer As New SpreadsheetGear.Windows.Forms.WorkbookExplorer(workbookSet)

            ' Set up some event handlers.
            AddHandler explorer.Shown, AddressOf WorkbookExplorer_Shown
            AddHandler explorer.FormClosed, AddressOf WorkbookExplorer_FormClosed

            ' Display the Workbook Explorer to the user.
            explorer.Show(WorkbookView)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowRangeExplorer(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Select a range of cells.
            WorkbookView.ActiveWorksheet.Cells("B2:D3").Select()

            ' Get the active workbook set.
            Dim workbookSet As SpreadsheetGear.IWorkbookSet = WorkbookView.ActiveWorkbookSet

            ' Set up the categories to display in the Range Explorer.
            ' NOTE: This enumeration can be used to limit available categories.
            Dim categoryFlags As SpreadsheetGear.Windows.Forms.RangeExplorerCategoryFlags = _
                SpreadsheetGear.Windows.Forms.RangeExplorerCategoryFlags.All

            ' Create the Range Explorer which operates on the current range selection.
            Dim explorer As New SpreadsheetGear.Windows.Forms.RangeExplorer(workbookSet, categoryFlags)

            ' Set up some event handlers.
            AddHandler explorer.Shown, AddressOf RangeExplorer_Shown
            AddHandler explorer.FormClosed, AddressOf RangeExplorer_FormClosed

            ' Display the Range Explorer to the user.
            explorer.Show(WorkbookView)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowChartExplorer(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the worksheet's shapes collection.
            Dim worksheet As SpreadsheetGear.IWorksheet = WorkbookView.ActiveWorksheet
            Dim shapes As SpreadsheetGear.Shapes.IShapes = WorkbookView.ActiveWorksheet.Shapes

            ' Delete any existing shapes in the shapes collection.
            While shapes.Count > 0
                shapes(0).Delete()
            End While

            ' Load some sample data.
            Dim dataRange As SpreadsheetGear.IRange = worksheet.Cells("A101:C105")
            dataRange.Formula = "=INT(RAND() * 10 + 5)"

            ' Add a chart.
            Dim shape As SpreadsheetGear.Shapes.IShape = shapes.AddChart(10, 10, 320, 150)
            Dim chart As SpreadsheetGear.Charts.IChart = shape.Chart

            ' Set the chart's source data range, plotting series in columns.
            chart.SetSourceData(dataRange, SpreadsheetGear.Charts.RowCol.Columns)

            ' Set the chart type.
            chart.ChartType = SpreadsheetGear.Charts.ChartType.ColumnClustered

            ' Select the chart shape.
            shape.Select(True)

            ' Get the active workbook set.
            Dim workbookSet As SpreadsheetGear.IWorkbookSet = WorkbookView.ActiveWorkbookSet

            ' Set up the categories to display in the Chart Explorer.
            ' NOTE: This enumeration can be used to limit available categories.
            Dim categoryFlags As SpreadsheetGear.Windows.Forms.ChartExplorerCategoryFlags = _
                SpreadsheetGear.Windows.Forms.ChartExplorerCategoryFlags.All

            ' Create the Chart Explorer which operates on the current chart selection.
            Dim explorer As New SpreadsheetGear.Windows.Forms.ChartExplorer(workbookSet, categoryFlags)

            ' Set up some event handlers.
            AddHandler explorer.Shown, AddressOf ChartExplorer_Shown
            AddHandler explorer.FormClosed, AddressOf ChartExplorer_FormClosed

            ' Display the Shape Explorer to the user.
            explorer.Show(WorkbookView)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    Private Sub ShowShapeExplorer(ByRef WorkbookView As SpreadsheetGear.Windows.Forms.WorkbookView)

        ' NOTE: Must acquire a workbook set lock.
        WorkbookView.GetLock()
        Try
            ' Get a reference to the worksheet's shapes collection.
            Dim shapes As SpreadsheetGear.Shapes.IShapes = WorkbookView.ActiveWorksheet.Shapes

            ' Delete any existing shapes in the shapes collection.
            While shapes.Count > 0
                shapes(0).Delete()
            End While

            ' Add a trapezoid.
            Dim shape As SpreadsheetGear.Shapes.IShape = shapes.AddShape( _
                SpreadsheetGear.Shapes.AutoShapeType.Trapezoid, 24, 24, 96, 96)

            ' Select the trapezoid.
            shape.Select(True)

            ' Get the active workbook set.
            Dim workbookSet As SpreadsheetGear.IWorkbookSet = WorkbookView.ActiveWorkbookSet

            ' Set up the categories to display in the Shape Explorer.
            ' NOTE: This enumeration can be used to limit available categories.
            Dim categoryFlags As SpreadsheetGear.Windows.Forms.ShapeExplorerCategoryFlags = _
                SpreadsheetGear.Windows.Forms.ShapeExplorerCategoryFlags.All

            ' Create the Shape Explorer which operates on the current shape selection.
            Dim explorer As New SpreadsheetGear.Windows.Forms.ShapeExplorer(workbookSet, categoryFlags)

            ' Set up some event handlers.
            AddHandler explorer.Shown, AddressOf ShapeExplorer_Shown
            AddHandler explorer.FormClosed, AddressOf ShapeExplorer_FormClosed

            ' Display the Shape Explorer to the user.
            explorer.Show(WorkbookView)
        Finally
            ' NOTE: Must release the workbook set lock.
            WorkbookView.ReleaseLock()
        End Try

    End Sub

    ' The following event handlers are only used to enable and
    ' disable the buttons used to display each individual form.

    Private Sub WorkbookDesigner_Shown(ByVal sender As System.Object, ByVal e As System.EventArgs)
        ButtonWorkbookDesigner.Enabled = False
    End Sub

    Private Sub WorkbookDesigner_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs)
        ButtonWorkbookDesigner.Enabled = True
    End Sub

    Private Sub WorkbookExplorer_Shown(ByVal sender As System.Object, ByVal e As System.EventArgs)
        ButtonWorkbookExplorer.Enabled = False
    End Sub

    Private Sub WorkbookExplorer_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs)
        ButtonWorkbookExplorer.Enabled = True
    End Sub

    Private Sub RangeExplorer_Shown(ByVal sender As System.Object, ByVal e As System.EventArgs)
        ButtonRangeExplorer.Enabled = False
    End Sub

    Private Sub RangeExplorer_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs)
        ButtonRangeExplorer.Enabled = True
    End Sub

    Private Sub ChartExplorer_Shown(ByVal sender As System.Object, ByVal e As System.EventArgs)
        ButtonChartExplorer.Enabled = False
    End Sub

    Private Sub ChartExplorer_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs)
        ButtonChartExplorer.Enabled = True
    End Sub

    Private Sub ShapeExplorer_Shown(ByVal sender As System.Object, ByVal e As System.EventArgs)
        ButtonShapeExplorer.Enabled = False
    End Sub

    Private Sub ShapeExplorer_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs)
        ButtonShapeExplorer.Enabled = True
    End Sub

End Class
